@@ -1,8 +1,8 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.21.3(b251bd952b84a3bdf68dad0141c37137dac55d64)
+ * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
  * Released under the MIT license
- * https://github.com/Microsoft/vscode/blob/master/LICENSE.txt
+ * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
 
 define("vs/editor/editor.main.nls.ko", {
@@ -21,6 +21,9 @@ define("vs/editor/editor.main.nls.ko", {
 		"입력",
 		"대/소문자 보존",
 	],
+	"vs/base/browser/ui/iconLabel/iconLabelHover": [
+		"로드 중...",
+	],
 	"vs/base/browser/ui/inputbox/inputBox": [
 		"오류: {0}",
 		"경고: {0}",
@@ -39,6 +42,9 @@ define("vs/editor/editor.main.nls.ko", {
 		"찾은 요소 없음",
 		"{1}개 요소 중 {0}개 일치",
 	],
+	"vs/base/common/actions": [
+		"(비어 있음)",
+	],
 	"vs/base/common/errorMessage": [
 		"{0}: {1}",
 		"시스템 오류가 발생했습니다({0}).",
@@ -71,6 +77,7 @@ define("vs/editor/editor.main.nls.ko", {
 	],
 	"vs/base/parts/quickinput/browser/quickInput": [
 		"뒤로",
+		"입력을 확인하려면 \'Enter\' 키를 누르고, 취소하려면 \'Esc\' 키를 누르세요.",
 		"{0} / {1}",
 		"결과의 범위를 축소하려면 입력하세요.",
 		"{0}개 결과",
@@ -86,11 +93,15 @@ define("vs/editor/editor.main.nls.ko", {
 	"vs/editor/browser/controller/coreCommands": [
 		"더 긴 줄로 이동하는 경우에도 끝에 고정",
 		"더 긴 줄로 이동하는 경우에도 끝에 고정",
+		"보조 커서가 제거됨",
 	],
 	"vs/editor/browser/controller/textAreaHandler": [
 		"편집기",
 		"현재 편집기에 액세스할 수 없습니다. 옵션을 보려면 {0}을(를) 누릅니다.",
 	],
+	"vs/editor/browser/core/keybindingCancellation": [
+		"편집기에서 취소 가능한 작업(예: \'참조 피킹\')을 실행하는지 여부",
+	],
 	"vs/editor/browser/editorExtensions": [
 		"실행 취소(&&U)",
 		"실행 취소",
@@ -103,9 +114,14 @@ define("vs/editor/editor.main.nls.ko", {
 		"커서 수는 {0}(으)로 제한되었습니다.",
 	],
 	"vs/editor/browser/widget/diffEditorWidget": [
+		"diff 편집기의 삽입에 대한 줄 데코레이션입니다.",
+		"diff 편집기의 제거에 대한 줄 데코레이션입니다.",
 		"파일 1개가 너무 커서 파일을 비교할 수 없습니다.",
 	],
 	"vs/editor/browser/widget/diffReview": [
+		"Diff 검토에서 \'삽입\'의 아이콘입니다.",
+		"Diff 검토에서 \'제거\'의 아이콘입니다.",
+		"Diff 검토에서 \'닫기\'의 아이콘입니다.",
 		"닫기",
 		"변경된 줄 없음",
 		"선 1개 변경됨",
@@ -134,6 +150,10 @@ define("vs/editor/editor.main.nls.ko", {
 		"끝에 자동 삽입된 공백을 제거합니다.",
 		"큰 파일에 대한 특수 처리로, 메모리를 많이 사용하는 특정 기능을 사용하지 않도록 설정합니다.",
 		"문서 내 단어를 기반으로 완성을 계산할지 여부를 제어합니다.",
+		"활성 문서에서만 단어를 제안합니다.",
+		"같은 언어의 모든 열린 문서에서 단어를 제안합니다.",
+		"모든 열린 문서에서 단어를 제안합니다.",
+		"단어 기반 완성이 컴퓨팅되는 문서에서 제어합니다.",
 		"모든 색 테마에 대해 의미 체계 강조 표시를 사용합니다.",
 		"모든 색 테마에 대해 의미 체계 강조 표시를 사용하지 않습니다.",
 		"의미 체계 강조 표시는 현재 색 테마의 `semanticHighlighting` 설정에 따라 구성됩니다.",
@@ -145,6 +165,9 @@ define("vs/editor/editor.main.nls.ko", {
 		"사용하도록 설정하면 Diff 편집기가 선행 또는 후행 공백의 변경 내용을 무시합니다.",
 		"diff 편집기에서 추가/제거된 변경 내용에 대해 +/- 표시기를 표시하는지 여부를 제어합니다.",
 		"편집기에서 CodeLens를 표시할 것인지 여부를 제어합니다.",
+		"줄이 바뀌지 않습니다.",
+		"뷰포트 너비에서 줄이 바뀝니다.",
+		"`#editor.wordWrap#` 설정에 따라 줄이 바뀝니다.",
 	],
 	"vs/editor/common/config/editorOptions": [
 		"편집기가 스크린 리더가 연결되면 플랫폼 API를 사용하여 감지합니다.",
@@ -156,16 +179,16 @@ define("vs/editor/editor.main.nls.ko", {
 		"선택 영역 없이 현재 줄 복사 여부를 제어합니다.",
 		"입력하는 동안 일치 항목을 찾기 위한 커서 이동 여부를 제어합니다.",
 		"편집기 선택에서 Find Widget의 검색 문자열을 시딩할지 여부를 제어합니다.",
-		"선택 항목에서 찾기를 자동으로 켜지 않음(기본값)",
-		"선택 항목에서 자동으로 항상 찾기 켜기",
+		"선택 영역에서 찾기를 자동으로 켜지 않습니다(기본값).",
+		"선택 영역에서 찾기를 항상 자동으로 켭니다.",
 		"여러 줄의 콘텐츠를 선택하면 선택 항목에서 찾기가 자동으로 켜집니다.",
 		"선택 영역에서 찾기를 자동으로 설정하는 조건을 제어합니다.",
 		"macOS에서 Find Widget이 공유 클립보드 찾기를 읽을지 수정할지 제어합니다.",
 		"위젯 찾기에서 편집기 맨 위에 줄을 추가해야 하는지 여부를 제어합니다. true인 경우 위젯 찾기가 표시되면 첫 번째 줄 위로 스크롤할 수 있습니다.",
 		"더 이상 일치하는 항목이 없을 때 검색을 처음이나 끝에서 자동으로 다시 시작할지 여부를 제어합니다.",
-		"글꼴 합자 사용하거나 사용하지 않도록 설정합니다.",
-		"명시적 글꼴 기능 설정입니다.",
-		"글꼴 합자 또는 글꼴 기능을 구성합니다.",
+		"글꼴 합자(\'calt\' 및 \'liga\' 글꼴 기능)를 사용하거나 사용하지 않도록 설정합니다. \'font-feature-settings\' CSS 속성의 세분화된 제어를 위해 문자열로 변경합니다.",
+		"명시적 \'font-feature-settings\' CSS 속성입니다. 합자를 켜거나 꺼야 하는 경우에만 부울을 대신 전달할 수 있습니다.",
+		"글꼴 합자 또는 글꼴 기능을 구성합니다. CSS \'font-feature-settings\' 속성의 값에 대해 합자 또는 문자열을 사용하거나 사용하지 않도록 설정하기 위한 부울일 수 있습니다.",
 		"글꼴 크기(픽셀)를 제어합니다.",
 		"\"표준\" 및 \"굵게\" 키워드 또는 1~1000 사이의 숫자만 허용됩니다.",
 		"글꼴 두께를 제어합니다. \"표준\" 및 \"굵게\" 키워드 또는 1~1000 사이의 숫자를 허용합니다.",
@@ -187,6 +210,9 @@ define("vs/editor/editor.main.nls.ko", {
 		"호버가 표시되기 전까지의 지연 시간(밀리초)을 제어합니다.",
 		"마우스를 해당 항목 위로 이동할 때 호버를 계속 표시할지 여부를 제어합니다.",
 		"편집기에서 코드 동작 전구를 사용하도록 설정합니다.",
+		"편집기에서 인레이 힌트를 사용하도록 설정합니다.",
+		"편집기에서 인레이 힌트의 글꼴 크기를 제어합니다. `0`으로 설정하면 `#editor.fontSize#`의 90%가 사용됩니다.",
+		"편집기에서 인레이 힌트의 글꼴 패밀리를 제어합니다.",
 		"줄 높이를 제어합니다. 글꼴 크기에서 줄 높이를 계산하려면 0을 사용합니다.",
 		"미니맵 표시 여부를 제어합니다.",
 		"미니맵의 크기는 편집기 내용과 동일하며 스크롤할 수 있습니다.",
@@ -201,7 +227,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"편집기의 위쪽 가장자리와 첫 번째 줄 사이의 공백을 제어합니다.",
 		"편집기의 아래쪽 가장자리와 마지막 줄 사이의 공백을 제어합니다.",
 		"입력과 동시에 매개변수 문서와 유형 정보를 표시하는 팝업을 사용하도록 설정합니다.",
-		" 매개변수 힌트 메뉴의 주기 혹은 목록의 끝에 도달하였을때 종료할 것인지 여부를 결정합니다. ",
+		"매개변수 힌트 메뉴의 주기 혹은 목록의 끝에 도달하였을때 종료할 것인지 여부를 결정합니다.",
 		"문자열 내에서 빠른 제안을 사용합니다.",
 		"주석 내에서 빠른 제안을 사용합니다.",
 		"문자열 및 주석 외부에서 빠른 제안을 사용합니다.",
@@ -214,19 +240,24 @@ define("vs/editor/editor.main.nls.ko", {
 		"이 편집기 눈금자에서 렌더링할 고정 폭 문자 수입니다.",
 		"이 편집기 눈금자의 색입니다.",
 		"특정 수의 고정 폭 문자 뒤에 세로 눈금자를 렌더링합니다. 여러 눈금자의 경우 여러 값을 사용합니다. 배열이 비어 있는 경우 눈금자가 그려지지 않습니다.",
+		"편집기에서 인라인 제안을 자동으로 표시할지 여부를 제어합니다.",
 		"커서의 텍스트 오른쪽을 덮어 쓰지않고 제안을 삽입합니다.",
 		"제안을 삽입하고 커서의 오른쪽 텍스트를 덮어씁니다.",
 		"완료를 수락할 때 단어를 덮어쓸지 여부를 제어합니다. 이것은 이 기능을 선택하는 확장에 따라 다릅니다.",
 		"제안 필터링 및 정렬에서 작은 오타를 설명하는지 여부를 제어합니다.",
-		"정렬할 때 커서 근처에 표시되는 단어를 우선할지 여부를 제어합니다.",
+		"정렬할 때 커서 근처에 표시되는 단어를 우선할지를 제어합니다.",
 		"저장된 제안 사항 선택 항목을 여러 작업 영역 및 창에서 공유할 것인지 여부를 제어합니다(`#editor.suggestSelection#` 필요).",
 		"활성 코드 조각이 빠른 제안을 방지하는지 여부를 제어합니다.",
 		"제안의 아이콘을 표시할지 여부를 제어합니다.",
-		"스크롤바를 표시하기 전에 IntelliSense가 표시할 제안 수를 제어합니다(최대 15개).",
+		"제안 위젯 하단의 상태 표시줄 가시성을 제어합니다.",
+		"편집기에서 제안 결과를 미리볼지 여부를 제어합니다.",
+		"제안 세부 정보가 레이블과 함께 인라인에 표시되는지 아니면 세부 정보 위젯에만 표시되는지를 제어합니다.",
+		"이 설정은 더 이상 사용되지 않습니다. 이제 제안 위젯의 크기를 조정할 수 있습니다.",
 		"이 설정은 더 이상 사용되지 않습니다. 대신 \'editor.suggest.showKeywords\'또는 \'editor.suggest.showSnippets\'와 같은 별도의 설정을 사용하세요.",
 		"사용하도록 설정되면 IntelliSense에 `메서드` 제안이 표시됩니다.",
 		"사용하도록 설정되면 IntelliSense에 \'함수\' 제안이 표시됩니다.",
 		"사용하도록 설정되면 IntelliSense에 \'생성자\' 제안이 표시됩니다.",
+		"사용하도록 설정되면 IntelliSense에 \'사용되지 않음\' 제안이 표시됩니다.",
 		"사용하도록 설정되면 IntelliSense에 \'필드\' 제안이 표시됩니다.",
 		"사용하도록 설정되면 IntelliSense에 \'변수\' 제안이 표시됩니다.",
 		"사용하도록 설정되면 IntelliSense에 \'클래스\' 제안이 표시됩니다.",
@@ -252,15 +283,17 @@ define("vs/editor/editor.main.nls.ko", {
 		"사용하도록 설정되면 IntelliSense에 \'코드 조각\' 제안이 표시됩니다.",
 		"IntelliSense를 사용하도록 설정하면 `user`-제안이 표시됩니다.",
 		"IntelliSense를 사용하도록 설정한 경우 `issues`-제안을 표시합니다.",
-		"제안 위젯 하단의 상태 표시줄 가시성을 제어합니다.",
+		"선행 및 후행 공백을 항상 선택해야 하는지 여부입니다.",
 		"커밋 문자에 대한 제안을 허용할지를 제어합니다. 예를 들어 JavaScript에서는 세미콜론(\';\')이 제안을 허용하고 해당 문자를 입력하는 커밋 문자일 수 있습니다.",
 		"텍스트를 변경할 때 `Enter` 키를 사용한 제안만 허용합니다.",
 		"\'Tab\' 키 외에 \'Enter\' 키에 대한 제안도 허용할지를 제어합니다. 새 줄을 삽입하는 동작과 제안을 허용하는 동작 간의 모호함을 없앨 수 있습니다.",
-		"화면 판독기가 읽을 수 있는 편집기의 줄 수를 제어합니다. 경고: 기본값보다 큰 숫자인 경우 성능에 영향을 미칩니다.",
+		"화면 읽기 프로그램에서 한 번에 읽을 수 있는 편집기 줄 수를 제어합니다. 화면 읽기 프로그램을 검색하면 기본값이 500으로 자동 설정됩니다. 경고: 기본값보다 큰 수의 경우 성능에 영향을 미칩니다.",
 		"편집기 콘텐츠",
 		"언어 구성을 사용하여 대괄호를 자동으로 닫을 경우를 결정합니다.",
 		"커서가 공백의 왼쪽에 있는 경우에만 대괄호를 자동으로 닫습니다.",
 		"사용자가 여는 괄호를 추가한 후 편집기에서 괄호를 자동으로 닫을지 여부를 제어합니다.",
+		"인접한 닫는 따옴표 또는 대괄호가 자동으로 삽입된 경우에만 제거합니다.",
+		"삭제할 때 편집기에서 인접한 닫는 따옴표 또는 대괄호를 제거해야 할지를 제어합니다.",
 		"닫기 따옴표 또는 대괄호가 자동으로 삽입된 경우에만 해당 항목 위에 입력합니다.",
 		"편집자가 닫는 따옴표 또는 대괄호 위에 입력할지 여부를 제어합니다.",
 		"언어 구성을 사용하여 따옴표를 자동으로 닫을 경우를 결정합니다.",
@@ -276,10 +309,13 @@ define("vs/editor/editor.main.nls.ko", {
 		"대괄호가 아닌 따옴표로 둘러쌉니다.",
 		"따옴표가 아닌 대괄호로 둘러쌉니다.",
 		"따옴표 또는 대괄호 입력 시 편집기가 자동으로 선택 영역을 둘러쌀지 여부를 제어합니다.",
+		"들여쓰기에 공백을 사용할 때 탭 문자의 선택 동작을 에뮬레이트합니다. 선택 영역이 탭 정지에 고정됩니다.",
 		"편집기에서 CodeLens를 표시할 것인지 여부를 제어합니다.",
+		"CodeLens의 글꼴 패밀리를 제어합니다.",
+		"CodeLens의 글꼴 크기(픽셀)를 제어합니다. \'0\'으로 설정하면 `#editor.fontSize#`의 90%가 사용됩니다.",
 		"편집기에서 인라인 색 데코레이터 및 색 선택을 렌더링할지를 제어합니다.",
 		"마우스와 키로 선택한 영역에서 열을 선택하도록 설정합니다.",
-		"터미널에서 선택한(블록 지정한) 텍스트가 클립보드로 자동 복사 여부를 제어합니다.\n\'true\'로 설정 할 시 선택할 때마다 클립보드로 복사 됩니다.",
+		"구문 강조 표시를 클립보드로 복사할지 여부를 제어합니다.",
 		"커서 애니메이션 스타일을 제어합니다.",
 		"매끄러운 캐럿 애니메이션의 사용 여부를 제어합니다.",
 		"커서 스타일을 제어합니다.",
@@ -303,6 +339,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"커서가 개요 눈금자에서 가려져야 하는지 여부를 제어합니다.",
 		"편집기에서 활성 들여쓰기 가이드를 강조 표시할지 여부를 제어합니다.",
 		"문자 간격(픽셀)을 제어합니다.",
+		"편집기에서 연결된 편집이 사용하도록 설정되었는지를 제어합니다. 언어에 따라 관련 기호(예: HTML 태그)가 편집 중에 업데이트됩니다.",
 		"편집기에서 링크를 감지하고 클릭할 수 있게 만들지 여부를 제어합니다.",
 		"일치하는 대괄호를 강조 표시합니다.",
 		"마우스 휠 스크롤 이벤트의 `deltaX` 및 `deltaY`에서 사용할 승수입니다.",
@@ -322,15 +359,16 @@ define("vs/editor/editor.main.nls.ko", {
 		"이동 정의 마우스 제스처가 항상 미리 보기 위젯을 열지 여부를 제어합니다.",
 		"빠른 제안을 표시하기 전까지의 지연 시간(밀리초)을 제어합니다.",
 		"편집기가 유형에 따라 자동으로 이름을 바꿀지 여부를 제어합니다.",
+		"사용되지 않습니다. 대신 `editor.linkedEditing`을 사용하세요.",
 		"편집기에서 제어 문자를 렌더링할지를 제어합니다.",
 		"편집기에서 들여쓰기 가이드를 렌더링할지를 제어합니다.",
 		"파일이 줄 바꿈으로 끝나면 마지막 줄 번호를 렌더링합니다.",
 		"제본용 여백과 현재 줄을 모두 강조 표시합니다.",
-		"편집기가 현재 줄 강조 표시를 렌더링하는 방식을 제어합니다. ",
+		"편집기가 현재 줄 강조 표시를 렌더링하는 방식을 제어합니다.",
 		"편집기에 포커스가 있는 경우에만 편집기에서 현재 줄 강조 표시를 렌더링해야 하는지 제어합니다.",
 		"단어 사이의 공백 하나를 제외한 공백 문자를 렌더링합니다.",
 		"선택한 텍스트에서만 공백 문자를 렌더링합니다.",
-		"후행 공백 문자만 렌더링",
+		"후행 공백 문자만 렌더링합니다.",
 		"편집기에서 공백 문자를 렌더링할 방법을 제어합니다.",
 		"선택 항목의 모서리를 둥글게 할지 여부를 제어합니다.",
 		"편집기에서 가로로 스크롤되는 범위를 벗어나는 추가 문자의 수를 제어합니다.",
@@ -350,7 +388,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"코드 조각이 다른 추천과 함께 표시되는지 여부 및 정렬 방법을 제어합니다.",
 		"편집기에서 애니메이션을 사용하여 스크롤할지 여부를 제어합니다.",
 		"제안 위젯의 글꼴 크기입니다. \'0\'으로 설정하면 \'#editor.fontSize#\'의 값이 사용됩니다.",
-		"제안 위젯의 줄 높이입니다. \'0\'으로 설정하면 `#editor.lineHeight#`의 값이 사용됩니다.",
+		"제안 위젯의 줄 높이입니다. \'0\'으로 설정하면 `#editor.lineHeight#`의 값이 사용됩니다. 최솟값은 8입니다.",
 		"트리거 문자를 입력할 때 제안을 자동으로 표시할지 여부를 제어합니다.",
 		"항상 첫 번째 제안을 선택합니다.",
 		"`log`가 최근에 완료되었으므로 추가 입력에서 제안을 선택하지 않은 경우 최근 제안을 선택하세요(예: `console.| -> console.log`).",
@@ -360,9 +398,9 @@ define("vs/editor/editor.main.nls.ko", {
 		"탭 완성을 사용하지 않도록 설정합니다.",
 		"접두사가 일치하는 경우 코드 조각을 탭 완료합니다. \'quickSuggestions\'를 사용하지 않을 때 가장 잘 작동합니다.",
 		"탭 완성을 사용하도록 설정합니다.",
+		"비정상적인 줄 종결자가 자동으로 제거됩니다.",
 		"비정상적인 줄 종결자가 무시됩니다.",
 		"제거할 비정상적인 줄 종결자 프롬프트입니다.",
-		"비정상적인 줄 종결자가 자동으로 제거됩니다.",
 		"문제를 일으킬 수 있는 비정상적인 줄 종결자를 제거합니다.",
 		"탭 정지 뒤에 공백을 삽입 및 삭제합니다.",
 		"단어 관련 탐색 또는 작업을 수행할 때 단어 구분 기호로 사용할 문자입니다.",
@@ -381,6 +419,38 @@ define("vs/editor/editor.main.nls.ko", {
 		"래핑 점 계산을 브라우저에 위임합니다. 이 알고리즘은 매우 느려서 대용량 파일의 경우 중단될 수 있지만 모든 경우에 적절히 작동합니다.",
 		"래핑 점을 계산하는 알고리즘을 제어합니다.",
 	],
+	"vs/editor/common/editorContextKeys": [
+		"편집기 텍스트에 포커스가 있는지 여부(커서가 깜박임)",
+		"편집기 또는 편집기 위젯에 포커스가 있는지 여부(예: 포커스가 찾기 위젯에 있음)",
+		"편집기 또는 서식 있는 텍스트 입력에 포커스가 있는지 여부(커서가 깜박임)",
+		"편집기가 읽기 전용인지 여부",
+		"컨텍스트가 diff 편집기인지 여부",
+		"\'editor.columnSelection\'을 사용하도록 설정되어 있는지 여부",
+		"편집기에 선택된 텍스트가 있는지 여부",
+		"편집기에 여러 개의 선택 항목이 있는지 여부",
+		"\'Tab\' 키를 누르면 편집기 밖으로 포커스가 이동하는지 여부",
+		"편집기 호버가 표시되는지 여부",
+		"편집기가 더 큰 편집기(예: 전자 필기장)에 속해 있는지 여부",
+		"편집기의 언어 식별자",
+		"편집기에 완성 항목 공급자가 있는지 여부",
+		"편집기에 코드 작업 공급자가 있는지 여부",
+		"편집기에 CodeLens 공급자가 있는지 여부",
+		"편집기에 정의 공급자가 있는지 여부",
+		"편집기에 선언 공급자가 있는지 여부",
+		"편집기에 구현 공급자가 있는지 여부",
+		"편집기에 형식 정의 공급자가 있는지 여부",
+		"편집기에 호버 공급자가 있는지 여부",
+		"편집기에 문서 강조 표시 공급자가 있는지 여부",
+		"편집기에 문서 기호 공급자가 있는지 여부",
+		"편집기에 참조 공급자가 있는지 여부",
+		"편집기에 이름 바꾸기 공급자가 있는지 여부",
+		"편집기에 시그니처 도움말 공급자가 있는지 여부",
+		"편집기에 인라인 힌트 공급자가 있는지 여부",
+		"편집기에 문서 서식 공급자가 있는지 여부",
+		"편집기에 문서 선택 서식 공급자가 있는지 여부",
+		"편집기에 여러 개의 문서 서식 공급자가 있는지 여부",
+		"편집기에 여러 개의 문서 선택 서식 공급자가 있는지 여부",
+	],
 	"vs/editor/common/model/editStack": [
 		"입력하는 중",
 	],
@@ -448,6 +518,8 @@ define("vs/editor/editor.main.nls.ko", {
 		"편집기 거터의 배경색입니다. 거터에는 글리프 여백과 행 수가 있습니다.",
 		"편집기의 불필요한(사용하지 않는) 소스 코드 테두리 색입니다.",
 		"편집기의 불필요한(사용하지 않는) 소스 코드 불투명도입니다. 예를 들어 \"#000000c0\"은 75% 불투명도로 코드를 렌더링합니다. 고대비 테마의 경우 페이드 아웃하지 않고 \'editorUnnecessaryCode.border\' 테마 색을 사용하여 불필요한 코드에 밑줄을 그으세요.",
+		"편집기에서 고스트 텍스트의 테두리 색입니다.",
+		"편집기에서 고스트 텍스트의 전경색입니다.",
 		"범위의 개요 눈금자 표식 색이 강조 표시됩니다. 기본 장식을 숨기지 않도록 색은 불투명하지 않아야 합니다.",
 		"오류의 개요 눈금자 마커 색입니다.",
 		"경고의 개요 눈금자 마커 색입니다.",
@@ -478,12 +550,17 @@ define("vs/editor/editor.main.nls.ko", {
 		"잘라내기(&&T)",
 		"잘라내기",
 		"잘라내기",
+		"잘라내기",
 		"복사(&&C)",
 		"복사",
 		"복사",
+		"복사",
+		"다음으로 복사",
+		"다음으로 복사",
 		"붙여넣기(&&P)",
 		"붙여넣기",
 		"붙여넣기",
+		"붙여넣기",
 		"구문을 강조 표시하여 복사",
 	],
 	"vs/editor/contrib/codeAction/codeActionCommands": [
@@ -540,48 +617,11 @@ define("vs/editor/editor.main.nls.ko", {
 		"커서 실행 취소",
 		"커서 다시 실행",
 	],
-	"vs/editor/contrib/documentSymbols/outlineTree": [
-		"배열 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"부울 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"클래스 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"색 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안에 표시됩니다.",
-		"상수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"생성자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"열거자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"열거자 멤버 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"이벤트 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"필드 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"파일 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"폴더 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"함수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"인터페이스 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"키 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"키워드 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"메서드 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"모듈 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"네임스페이스 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"null 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"숫자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"개체 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"연산자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"패키지 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"속성 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"참조 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"코드 조각 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"문자열 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"구조 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"텍스트 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
-		"형식 매개변수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"단위 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-		"변수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
-	],
 	"vs/editor/contrib/find/findController": [
 		"찾기",
 		"찾기(&&F)",
 		"선택 영역에서 찾기",
 		"다음 찾기",
-		"다음 찾기",
-		"이전 찾기",
 		"이전 찾기",
 		"다음 선택 찾기",
 		"이전 선택 찾기",
@@ -589,6 +629,13 @@ define("vs/editor/editor.main.nls.ko", {
 		"바꾸기(&&R)",
 	],
 	"vs/editor/contrib/find/findWidget": [
+		"편집기 찾기 위젯에서 \'선택 영역에서 찾기\'의 아이콘입니다.",
+		"편집기 찾기 위젯이 축소되었음을 나타내는 아이콘입니다.",
+		"편집기 찾기 위젯이 확장되었음을 나타내는 아이콘입니다.",
+		"편집기 찾기 위젯에서 \'바꾸기\'의 아이콘입니다.",
+		"편집기 찾기 위젯에서 \'모두 바꾸기\'의 아이콘입니다.",
+		"편집기 찾기 위젯에서 \'이전 찾기\'의 아이콘입니다.",
+		"편집기 찾기 위젯에서 \'다음 찾기\'의 아이콘입니다.",
 		"찾기",
 		"찾기",
 		"이전 일치",
@@ -618,12 +665,18 @@ define("vs/editor/editor.main.nls.ko", {
 		"모든 블록 코멘트를 접기",
 		"모든 영역 접기",
 		"모든 영역 펼치기",
+		"선택한 영역을 제외한 모든 영역 접기",
+		"선택한 영역을 제외한 모든 영역 펼치기",
 		"모두 접기",
 		"모두 펼치기",
 		"수준 {0} 접기",
 		"접힌 범위의 배경색입니다. 색은 기본 장식을 숨기지 않기 위해 불투명해서는 안 됩니다.",
 		"편집기 여백의 접기 컨트롤 색입니다.",
 	],
+	"vs/editor/contrib/folding/foldingDecorations": [
+		"편집기 문자 모양 여백에서 확장된 범위의 아이콘입니다.",
+		"편집기 문자 모양 여백에서 축소된 범위의 아이콘입니다.",
+	],
 	"vs/editor/contrib/fontZoom/fontZoom": [
 		"편집기 글꼴 확대",
 		"편집기 글꼴 축소",
@@ -641,7 +694,9 @@ define("vs/editor/editor.main.nls.ko", {
 	],
 	"vs/editor/contrib/gotoError/gotoError": [
 		"다음 문제로 이동 (오류, 경고, 정보)",
+		"다음 마커로 이동의 아이콘입니다.",
 		"이전 문제로 이동 (오류, 경고, 정보)",
+		"이전 마커로 이동의 아이콘입니다.",
 		"파일의 다음 문제로 이동 (오류, 경고, 정보)",
 		"다음 문제(&&P)",
 		"파일의 이전 문제로 이동 (오류, 경고, 정보)",
@@ -652,7 +707,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"경고",
 		"정보",
 		"힌트",
-		"{1}의 {0}입니다.",
+		"{1}의 {0}입니다. ",
 		"문제 {1}개 중 {0}개",
 		"문제 {1}개 중 {0}개",
 		"편집기 표식 탐색 위젯 오류 색입니다.",
@@ -705,6 +760,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"{0}개 정의를 표시하려면 클릭하세요.",
 	],
 	"vs/editor/contrib/gotoSymbol/peek/referencesController": [
+		"\'참조 피킹\' 또는 \'정의 피킹\'과 같이 참조 피킹이 표시되는지 여부",
 		"로드 중...",
 		"{0}({1})",
 	],
@@ -720,6 +776,7 @@ define("vs/editor/editor.main.nls.ko", {
 	],
 	"vs/editor/contrib/gotoSymbol/referencesModel": [
 		"{2}열, {1}줄, {0}의 기호",
+		"열 {2}, {3}의 줄 {1}에 있는 {0}의 기호",
 		"{0}의 기호 1개, 전체 경로 {1}",
 		"{1}의 기호 {0}개, 전체 경로 {2}",
 		"결과 없음",
@@ -728,6 +785,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"{1}개 파일에서 기호 {0}개를 찾았습니다.",
 	],
 	"vs/editor/contrib/gotoSymbol/symbolNavigation": [
+		"키보드만으로 탐색할 수 있는 기호 위치가 있는지 여부",
 		"{1}의 {0} 기호, 다음의 경우 {2}",
 		"{1}의 기호 {0}",
 	],
@@ -735,9 +793,12 @@ define("vs/editor/editor.main.nls.ko", {
 		"가리키기 표시",
 		"정의 미리 보기 가리킨 항목 표시",
 	],
-	"vs/editor/contrib/hover/modesContentHover": [
+	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"로드 중...",
+	],
+	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"문제 보기",
+		"빠른 수정을 사용할 수 없음",
 		"빠른 수정을 확인하는 중...",
 		"빠른 수정을 사용할 수 없음",
 		"빠른 수정...",
@@ -757,6 +818,18 @@ define("vs/editor/editor.main.nls.ko", {
 		"줄 다시 들여쓰기",
 		"선택한 줄 다시 들여쓰기",
 	],
+	"vs/editor/contrib/inlineCompletions/ghostTextController": [
+		"인라인 제안 표시 여부",
+		"인라인 제안이 공백으로 시작하는지 여부",
+		"다음 인라인 제안 표시",
+		"이전 인라인 제안 표시",
+		"인라인 제안 트리거",
+	],
+	"vs/editor/contrib/inlineCompletions/inlineCompletionsHoverParticipant": [
+		"다음",
+		"이전",
+		"수락",
+	],
 	"vs/editor/contrib/linesOperations/linesOperations": [
 		"위에 줄 복사",
 		"위에 줄 복사(&&C)",
@@ -783,6 +856,11 @@ define("vs/editor/editor.main.nls.ko", {
 		"대문자로 변환",
 		"소문자로 변환",
 		"단어의 첫 글자를 대문자로 변환",
+		"스네이크 표기법으로 변환",
+	],
+	"vs/editor/contrib/linkedEditing/linkedEditing": [
+		"연결된 편집 시작",
+		"형식의 편집기에서 자동으로 이름을 바꿀 때의 배경색입니다.",
 	],
 	"vs/editor/contrib/links/links": [
 		"명령 실행",
@@ -791,14 +869,18 @@ define("vs/editor/editor.main.nls.ko", {
 		"Ctrl+클릭",
 		"Option+클릭",
 		"Alt+클릭",
+		"명령 {0} 실행",
 		"{0} 형식이 올바르지 않으므로 이 링크를 열지 못했습니다",
 		"대상이 없으므로 이 링크를 열지 못했습니다.",
 		"링크 열기",
 	],
 	"vs/editor/contrib/message/messageController": [
+		"편집기에서 현재 인라인 메시지를 표시하는지 여부",
 		"읽기 전용 편집기에서는 편집할 수 없습니다.",
 	],
 	"vs/editor/contrib/multicursor/multicursor": [
+		"커서가 추가됨: {0}",
+		"커서가 추가됨: {0}",
 		"위에 커서 추가",
 		"위에 커서 추가(&&A)",
 		"아래에 커서 추가",
@@ -821,9 +903,12 @@ define("vs/editor/editor.main.nls.ko", {
 		"매개 변수 힌트 트리거",
 	],
 	"vs/editor/contrib/parameterHints/parameterHintsWidget": [
+		"다음 매개 변수 힌트 표시의 아이콘입니다.",
+		"이전 매개 변수 힌트 표시의 아이콘입니다.",
 		"{0}, 힌트",
 	],
 	"vs/editor/contrib/peekView/peekView": [
+		"현재 코드 편집기가 피킹 내부에 포함되었는지 여부",
 		"닫기",
 		"Peek 뷰 제목 영역의 배경색입니다.",
 		"Peek 뷰 제목 색입니다.",
@@ -842,7 +927,7 @@ define("vs/editor/editor.main.nls.ko", {
 	],
 	"vs/editor/contrib/quickAccess/gotoLineQuickAccess": [
 		"우선 텍스트 편집기를 열고 줄로 이동합니다.",
-		"{0} 줄 및 {1} 열로 이동합니다.",
+		"줄 {0} 및 문자 {1}(으)로 이동합니다.",
 		"{0} 줄로 이동합니다.",
 		"현재 줄: {0}, 문자: {1} 이동할 줄 1~{2} 사이의 번호를 입력합니다.",
 		"현재 줄: {0}, 문자: {1}. 이동할 줄 번호를 입력합니다.",
@@ -882,10 +967,6 @@ define("vs/editor/editor.main.nls.ko", {
 		"필드({0})",
 		"상수({0})",
 	],
-	"vs/editor/contrib/rename/onTypeRename": [
-		"유형별 이름 바꾸기 기호",
-		"형식의 편집기에서 자동으로 이름을 바꿀 때의 배경색입니다.",
-	],
 	"vs/editor/contrib/rename/rename": [
 		"결과가 없습니다.",
 		"위치 이름을 바꾸는 중 알 수 없는 오류가 발생했습니다.",
@@ -898,6 +979,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"이름을 바꾸기 전에 변경 내용을 미리 볼 수 있는 기능 사용/사용 안 함",
 	],
 	"vs/editor/contrib/rename/renameInputField": [
+		"입력 이름 바꾸기 위젯이 표시되는지 여부",
 		"입력 이름을 바꾸세요. 새 이름을 입력한 다음 [Enter] 키를 눌러 커밋하세요.",
 		"이름 바꾸기 {0}, 미리 보기 {1}",
 	],
@@ -907,6 +989,11 @@ define("vs/editor/editor.main.nls.ko", {
 		"선택 영역 축소",
 		"선택 영역 축소(&&S)",
 	],
+	"vs/editor/contrib/snippet/snippetController2": [
+		"현재 편집기가 코드 조각 모드인지 여부",
+		"코드 조각 모드일 때 다음 탭 정지가 있는지 여부",
+		"코드 조각 모드일 때 이전 탭 정지가 있는지 여부",
+	],
 	"vs/editor/contrib/snippet/snippetVariables": [
 		"일요일",
 		"월요일",
@@ -947,31 +1034,87 @@ define("vs/editor/editor.main.nls.ko", {
 		"11월",
 		"12월",
 	],
+	"vs/editor/contrib/suggest/suggest": [
+		"제안이 표시되는지 여부",
+		"제안 세부 정보가 표시되는지 여부",
+		"선택할 수 있는 여러 제안이 있는지 여부",
+		"현재 제안을 삽입하면 변경 내용이 생성되는지 또는 모든 항목이 이미 입력되었는지 여부",
+		"<Enter> 키를 누를 때 제안이 삽입되는지 여부",
+		"현재 제안에 삽입 및 바꾸기 동작이 있는지 여부",
+		"기본 동작이 삽입인지 또는 바꾸기인지 여부",
+		"현재 제안에서 추가 세부 정보를 확인하도록 지원하는지 여부",
+	],
 	"vs/editor/contrib/suggest/suggestController": [
-		"Accepting \'{0}\' made {1} additional edits",
+		"{0}의 {1}개의 수정사항을 수락하는 중",
 		"제안 항목 트리거",
-		"삽입하려면 {0}",
-		"삽입하려면 {0}",
-		"교체하려면 {0}",
-		"교체하려면 {0}",
-		"삽입하려면 {0}",
+		"삽입",
+		"삽입",
+		"바꾸기",
+		"바꾸기",
+		"삽입",
 		"간단히 표시",
 		"더 보기",
+		"제안 위젯 크기 다시 설정",
 	],
 	"vs/editor/contrib/suggest/suggestWidget": [
 		"제안 위젯의 배경색입니다.",
 		"제안 위젯의 테두리 색입니다.",
 		"제안 위젯의 전경색입니다.",
+		"제한 위젯에서 선택된 항목의 전경색입니다.",
 		"제한 위젯에서 선택된 항목의 배경색입니다.",
 		"제안 위젯의 일치 항목 강조 표시 색입니다.",
-		"자세한 정보({0})",
-		"간단히 표시({0})",
-		"로드 중...",
+		"항목에 포커스가 있을 때 추천 위젯에서 일치하는 항목의 색이 강조 표시됩니다.",
 		"로드 중...",
 		"제안 항목이 없습니다.",
 		"{0}, 문서: {1}",
 		"제안",
 	],
+	"vs/editor/contrib/suggest/suggestWidgetDetails": [
+		"닫기",
+		"로드 중...",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetRenderer": [
+		"제안 위젯에서 자세한 정보의 아이콘입니다.",
+		"자세한 정보",
+	],
+	"vs/editor/contrib/suggest/suggestWidgetStatus": [
+		"{0} ({1})",
+	],
+	"vs/editor/contrib/symbolIcons/symbolIcons": [
+		"배열 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"부울 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"클래스 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"색 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안에 표시됩니다.",
+		"상수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"생성자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"열거자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"열거자 멤버 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"이벤트 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"필드 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"파일 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"폴더 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"함수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"인터페이스 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"키 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"키워드 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"메서드 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"모듈 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"네임스페이스 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"null 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"숫자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"개체 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"연산자 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"패키지 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"속성 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"참조 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"코드 조각 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"문자열 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"구조 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"텍스트 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 나타납니다.",
+		"형식 매개변수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"단위 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+		"변수 기호의 전경색입니다. 이러한 기호는 개요, 이동 경로 및 제안 위젯에 표시됩니다.",
+	],
 	"vs/editor/contrib/toggleTabFocusMode/toggleTabFocusMode": [
 		"<Tab> 키로 포커스 이동 설정/해제",
 		"이제 <Tab> 키를 누르면 포커스가 다음 포커스 가능한 요소로 이동합니다.",
@@ -998,16 +1141,27 @@ define("vs/editor/editor.main.nls.ko", {
 		"이전 강조 기호로 이동",
 		"기호 강조 표시 트리거",
 	],
+	"vs/editor/contrib/wordOperations/wordOperations": [
+		"단어 삭제",
+	],
 	"vs/platform/actions/browser/menuEntryActionViewItem": [
 		"{0}({1})",
+		"{0}({1})",
 	],
 	"vs/platform/configuration/common/configurationRegistry": [
 		"기본 언어 구성 재정의",
 		"언어에 대해 재정의할 편집기 설정을 구성합니다.",
 		"이 설정은 언어별 구성을 지원하지 않습니다.",
+		"빈 속성을 등록할 수 없음",
 		"\'{0}\'을(를) 등록할 수 없습니다. 이는 언어별 편집기 설정을 설명하는 속성 패턴인 \'\\\\[.*\\\\]$\'과(와) 일치합니다. \'configurationDefaults\' 기여를 사용하세요.",
 		"\'{0}\'을(를) 등록할 수 없습니다. 이 속성은 이미 등록되어 있습니다.",
 	],
+	"vs/platform/contextkey/browser/contextKeyService": [
+		"컨텍스트 키에 대한 정보를 반환하는 명령",
+	],
+	"vs/platform/contextkey/common/contextkeys": [
+		"운영 체제가 Windows인지 여부",
+	],
 	"vs/platform/keybinding/common/abstractKeybindingService": [
 		"({0})을(를) 눌렀습니다. 둘째 키는 잠시 기다렸다가 누르십시오...",
 		"키 조합({0}, {1})은 명령이 아닙니다.",
@@ -1017,7 +1171,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"Windows와 Linux의 \'Control\'을 macOS의 \'Command\'로 매핑합니다.",
 		"Windows와 Linux의 \'Alt\'를 macOS의 \'Option\'으로 매핑합니다.",
 		"마우스로 트리와 목록의 항목을 다중 선택에 추가할 때 사용할 한정자입니다(예를 들어 탐색기에서 편집기와 SCM 보기를 여는 경우). \'옆에서 열기\' 마우스 제스처(지원되는 경우)는 다중 선택 한정자와 충돌하지 않도록 조정됩니다.",
-		"트리와 목록에서 마우스를 사용하여 항목을 여는 방법을 제어합니다(지원되는 경우). 트리에서 자식 항목이 있는 부모 항목의 경우 이 설정은 부모 항목을 한 번 클릭으로 확장할지 또는 두 번 클릭으로 확장할지 여부를 제어합니다. 일부 트리와 목록에서는 이 설정을 적용할 수 없는 경우 무시하도록 선택할 수 있습니다. ",
+		"트리와 목록에서 마우스를 사용하여 항목을 여는 방법을 제어합니다(지원되는 경우). 일부 트리와 목록에서는 이 설정을 적용할 수 없는 경우 무시하도록 선택할 수 있습니다.",
 		"워크벤치에서 목록 및 트리의 가로 스크롤 여부를 제어합니다. 경고: 이 설정을 켜면 성능에 영향을 미칩니다.",
 		"트리 들여쓰기를 픽셀 단위로 제어합니다.",
 		"트리에서 들여쓰기 가이드를 렌더링할지 여부를 제어합니다.",
@@ -1027,6 +1181,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"키보드 탐색 필터링에서는 키보드 입력과 일치하지 않는 요소를 모두 필터링하여 숨깁니다.",
 		"워크벤치의 목록 및 트리 키보드 탐색 스타일을 제어합니다. 간소화하고, 강조 표시하고, 필터링할 수 있습니다.",
 		"목록 및 트리에서 키보드 탐색이 입력만으로 자동 트리거되는지 여부를 제어합니다. \'false\'로 설정하면 \'list.toggleKeyboardNavigation\' 명령을 실행할 때만 키보드 탐색이 트리거되어 바로 가기 키를 할당할 수 있습니다.",
+		"폴더 이름을 클릭할 때 트리 폴더가 확장되는 방법을 제어합니다. 일부 트리와 목록에서는 이 설정을 적용할 수 없는 경우 무시하도록 선택할 수 있습니다.",
 	],
 	"vs/platform/markers/common/markers": [
 		"오류",
@@ -1038,6 +1193,7 @@ define("vs/editor/editor.main.nls.ko", {
 		"최근에 사용한 항목",
 		"기타 명령",
 		"명령 \'{0}\'에서 오류({1})가 발생했습니다.",
+		"확인",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"전역 명령",
@@ -1081,10 +1237,13 @@ define("vs/editor/editor.main.nls.ko", {
 		"마우스로 가리킬 때 스크롤 막대 슬라이더 배경색입니다.",
 		"클릭된 상태일 때 스크롤 막대 슬라이더 배경색입니다.",
 		"장기 작업을 대상으로 표시될 수 있는 진행률 표시줄의 배경색입니다.",
+		"편집기에서 오류 텍스트의 배경색입니다. 기본 장식을 숨기지 않도록 색은 불투명하지 않아야 합니다.",
 		"편집기 내 오류 표시선의 전경색입니다.",
 		"편집기에서 오류 상자의 테두리 색입니다.",
+		"편집기에서 경고 텍스트의 배경색입니다. 기본 장식을 숨기지 않도록 색은 불투명하지 않아야 합니다.",
 		"편집기 내 경고 표시선의 전경색입니다.",
 		"편집기에서 경고 상자의 테두리 색입니다.",
+		"편집기에서 정보 텍스트의 배경색입니다. 기본 장식을 숨기지 않도록 색은 불투명하지 않아야 합니다.",
 		"편집기 내 정보 표시선의 전경색입니다.",
 		"편집기에서 정보 상자의 테두리 색입니다.",
 		"편집기에서 힌트 표시선의 전경색입니다.",
@@ -1100,6 +1259,10 @@ define("vs/editor/editor.main.nls.ko", {
 		"빠른 선택기 제목 배경색. 이 빠른 선택기 위젯은 명령 팔레트와 같은 선택기를 위한 컨테이너입니다.",
 		"그룹화 레이블에 대한 빠른 선택기 색입니다.",
 		"그룹화 테두리에 대한 빠른 선택기 색입니다.",
+		"키 바인딩 레이블 배경색입니다. 키 바인딩 레이블은 바로 가기 키를 나타내는 데 사용됩니다.",
+		"키 바인딩 레이블 전경색입니다. 키 바인딩 레이블은 바로 가기 키를 나타내는 데 사용됩니다.",
+		"키 바인딩 레이블 테두리 색입니다. 키 바인딩 레이블은 바로 가기 키를 나타내는 데 사용됩니다.",
+		"키 바인딩 레이블 테두리 아래쪽 색입니다. 키 바인딩 레이블은 바로 가기 키를 나타내는 데 사용됩니다.",
 		"편집기 선택 영역의 색입니다.",
 		"고대비를 위한 선택 텍스트의 색입니다.",
 		"비활성 편집기의 선택 항목 색입니다. 기본 장식을 숨기지 않도록 색은 불투명하지 않아야 합니다.",
@@ -1117,6 +1280,8 @@ define("vs/editor/editor.main.nls.ko", {
 		"편집기 호버의 테두리 색입니다.",
 		"편집기 호버 상태 표시줄의 배경색입니다.",
 		"활성 링크의 색입니다.",
+		"인라인 힌트의 전경색",
+		"인라인 힌트의 배경색",
 		"전구 작업 아이콘에 사용되는 색상입니다.",
 		"전구 자동 수정 작업 아이콘에 사용되는 색상입니다.",
 		"삽입된 텍스트의 배경색입니다. 기본 장식을 숨기지 않도록 색은 불투명하지 않아야 합니다.",
@@ -1127,19 +1292,26 @@ define("vs/editor/editor.main.nls.ko", {
 		"diff 편집기의 대각선 채우기 색입니다. 대각선 채우기는 diff 나란히 보기에서 사용됩니다.",
 		"목록/트리가 활성 상태인 경우 포커스가 있는 항목의 목록/트리 배경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 활성 상태인 경우 포커스가 있는 항목의 목록/트리 전경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
+		"목록/트리가 활성 상태인 경우 포커스가 있는 항목의 목록/트리 윤곽선 색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 활성 상태인 경우 선택한 항목의 목록/트리 배경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 활성 상태인 경우 선택한 항목의 목록/트리 전경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 비활성 상태인 경우 선택한 항목의 목록/트리 배경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 비활성 상태인 경우 선택한 항목의 목록/트리 전경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"목록/트리가 비활성 상태인 경우 포커스가 있는 항목의 목록/트리 배경색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
+		"목록/트리가 비활성 상태인 경우 포커스가 있는 항목의 목록/트리 윤곽선 색입니다. 목록/트리가 활성 상태이면 키보드 포커스를 가지며, 비활성 상태이면 포커스가 없습니다.",
 		"마우스로 항목을 가리킬 때 목록/트리 배경입니다.",
 		"마우스로 항목을 가리킬 때 목록/트리 전경입니다.",
 		"마우스로 항목을 이동할 때 목록/트리 끌어서 놓기 배경입니다.",
 		"목록/트리 내에서 검색할 때 일치 항목 강조 표시의 목록/트리 전경색입니다.",
+		"목록/트리 내에서 검색할 때 일치 항목의 목록/트리 전경색이 능동적으로 포커스가 있는 항목을 강조 표시합니다.",
 		"목록 및 트리에서 형식 필터 위젯의 배경색입니다.",
 		"목록 및 트리에서 형식 필터 위젯의 윤곽선 색입니다.",
 		"일치하는 항목이 없을 때 목록 및 트리에서 표시되는 형식 필터 위젯의 윤곽선 색입니다.",
 		"들여쓰기 가이드의 트리 스트로크 색입니다.",
+		"들여쓰기 가이드의 트리 스트로크 색입니다.",
+		"대신 quickInputList.focusBackground를 사용하세요.",
+		"포커스가 있는 항목의 빠른 선택기 전경색입니다.",
+		"포커스가 있는 항목의 빠른 선택기 배경색입니다.",
 		"메뉴 테두리 색입니다.",
 		"메뉴 항목 전경색입니다.",
 		"메뉴 항목 배경색입니다.",
@@ -1165,6 +1337,11 @@ define("vs/editor/editor.main.nls.ko", {
 		"문제 경고 아이콘에 사용되는 색입니다.",
 		"문제 정보 아이콘에 사용되는 색입니다.",
 	],
+	"vs/platform/theme/common/iconRegistry": [
+		"사용할 글꼴의 ID입니다. 설정하지 않으면 첫 번째로 정의한 글꼴이 사용됩니다.",
+		"아이콘 정의와 연결된 글꼴 문자입니다.",
+		"위젯에서 닫기 작업의 아이콘입니다.",
+	],
 	"vs/platform/undoRedo/common/undoRedoService": [
 		"{0} 파일이 닫히고 디스크에서 수정되었습니다.",
 		"{0} 파일은 호환되지 않는 방식으로 수정되었습니다.",
@@ -1178,6 +1355,9 @@ define("vs/editor/editor.main.nls.ko", {
 		"이 파일 실행 취소",
 		"취소",
 		"실행 취소 또는 다시 실행 작업이 이미 실행 중이므로 \'{0}\'을(를) 실행 취소할 수 없습니다.",
+		"\'{0}\'을(를) 실행 취소하시겠습니까?",
+		"실행 취소",
+		"취소",
 		"모든 파일에서 \'{0}\'을(를) 다시 실행할 수 없습니다. {1}",
 		"모든 파일에서 \'{0}\'을(를) 다시 실행할 수 없습니다. {1}",
 		"{1}에 변경 내용이 적용되었으므로 모든 파일에서 \'{0}\'을(를) 다시 실행할 수 없습니다.",
