@@ -1,8 +1,6 @@
-import requiredArgs from "../_lib/requiredArgs/index.js";
-import getDay from "../getDay/index.js";
 import addDays from "../addDays/index.js";
-import toDate from "../toDate/index.js";
-var baseMap = [7, 6, 5, 4, 3, 2, 1];
+import getDay from "../getDay/index.js";
+import requiredArgs from "../_lib/requiredArgs/index.js";
 /**
  * @name nextDay
  * @category Weekday Helpers
@@ -17,28 +15,19 @@ var baseMap = [7, 6, 5, 4, 3, 2, 1];
  * @throws {TypeError} - 2 arguments required
  *
  * @example
- * When is the next Monday after Mar, 20, 2020?
+ * // When is the next Monday after Mar, 20, 2020?
  * const result = nextDay(new Date(2020, 2, 20), 1)
- * => Mon Mar 23 2020 00:00:00
+ * //=> Mon Mar 23 2020 00:00:00
  *
  * @example
- * When is the next Tuesday after Mar, 21, 2020?
+ * // When is the next Tuesday after Mar, 21, 2020?
  * const result = nextDay(new Date(2020, 2, 21), 2)
- * => Tue Mar 24 2020 00:00:00
- **/
+ * //=> Tue Mar 24 2020 00:00:00
+ */
 
 export default function nextDay(date, day) {
   requiredArgs(2, arguments);
-  var map = genMap(day);
-  return addDays(toDate(date), map[getDay(toDate(date))]);
-}
-
-function genMap(daysToMove) {
-  if (daysToMove === 0) {
-    return baseMap;
-  } else {
-    var mapStart = baseMap.slice(-daysToMove);
-    var mapEnd = baseMap.slice(0, baseMap.length - daysToMove);
-    return mapStart.concat(mapEnd);
-  }
+  var delta = day - getDay(date);
+  if (delta <= 0) delta += 7;
+  return addDays(date, delta);
 }
\ No newline at end of file
