@@ -9,71 +9,22 @@ import { StandardMouseEvent } from './mouseEvent.js';
 import { TimeoutTimer } from '../common/async.js';
 import { onUnexpectedError } from '../common/errors.js';
 import { Emitter } from '../common/event.js';
-import { Disposable, toDisposable } from '../common/lifecycle.js';
+import { Disposable, DisposableStore, toDisposable } from '../common/lifecycle.js';
 import * as platform from '../common/platform.js';
-import { coalesce } from '../common/arrays.js';
-import { Schemas, RemoteAuthorities } from '../common/network.js';
+import { FileAccess, RemoteAuthorities } from '../common/network.js';
 import { BrowserFeatures } from './canIUse.js';
 export function clearNode(node) {
     while (node.firstChild) {
-        node.removeChild(node.firstChild);
+        node.firstChild.remove();
     }
 }
 /**
- * @deprecated use `node.remove()` instead
+ * @deprecated Use node.isConnected directly
  */
-export function removeNode(node) {
-    if (node.parentNode) {
-        node.parentNode.removeChild(node);
-    }
-}
 export function isInDOM(node) {
-    while (node) {
-        if (node === document.body) {
-            return true;
-        }
-        node = node.parentNode || node.host;
-    }
-    return false;
+    var _a;
+    return (_a = node === null || node === void 0 ? void 0 : node.isConnected) !== null && _a !== void 0 ? _a : false;
 }
-const _classList = new class {
-    hasClass(node, className) {
-        return Boolean(className) && node.classList && node.classList.contains(className);
-    }
-    addClasses(node, ...classNames) {
-        classNames.forEach(nameValue => nameValue.split(' ').forEach(name => this.addClass(node, name)));
-    }
-    addClass(node, className) {
-        if (className && node.classList) {
-            node.classList.add(className);
-        }
-    }
-    removeClass(node, className) {
-        if (className && node.classList) {
-            node.classList.remove(className);
-        }
-    }
-    removeClasses(node, ...classNames) {
-        classNames.forEach(nameValue => nameValue.split(' ').forEach(name => this.removeClass(node, name)));
-    }
-    toggleClass(node, className, shouldHaveIt) {
-        if (node.classList) {
-            node.classList.toggle(className, shouldHaveIt);
-        }
-    }
-};
-/** @deprecated ES6 - use classList*/
-export const hasClass = _classList.hasClass.bind(_classList);
-/** @deprecated ES6 - use classList*/
-export const addClass = _classList.addClass.bind(_classList);
-/** @deprecated ES6 - use classList*/
-export const addClasses = _classList.addClasses.bind(_classList);
-/** @deprecated ES6 - use classList*/
-export const removeClass = _classList.removeClass.bind(_classList);
-/** @deprecated ES6 - use classList*/
-export const removeClasses = _classList.removeClasses.bind(_classList);
-/** @deprecated ES6 - use classList*/
-export const toggleClass = _classList.toggleClass.bind(_classList);
 class DomListener {
     constructor(node, type, handler, options) {
         this._node = node;
@@ -255,7 +206,7 @@ class AnimationFrameQueueItem {
         }
     };
 })();
-const MINIMUM_TIME_MS = 16;
+const MINIMUM_TIME_MS = 8;
 const DEFAULT_EVENT_MERGER = function (lastEvent, currentEvent) {
     return currentEvent;
 };
@@ -296,14 +247,7 @@ export function getClientArea(element) {
     }
     // If visual view port exits and it's on mobile, it should be used instead of window innerWidth / innerHeight, or document.body.clientWidth / document.body.clientHeight
     if (platform.isIOS && window.visualViewport) {
-        const width = window.visualViewport.width;
-        const height = window.visualViewport.height - (browser.isStandalone
-            // in PWA mode, the visual viewport always includes the safe-area-inset-bottom (which is for the home indicator)
-            // even when you are using the onscreen monitor, the visual viewport will include the area between system statusbar and the onscreen keyboard
-            // plus the area between onscreen keyboard and the bottom bezel, which is 20px on iOS.
-            ? (20 + 4) // + 4px for body margin
-            : 0);
-        return new Dimension(width, height);
+        return new Dimension(window.visualViewport.width, window.visualViewport.height);
     }
     // Try innerWidth / innerHeight
     if (window.innerWidth && window.innerHeight) {
@@ -381,6 +325,34 @@ export class Dimension {
         this.width = width;
         this.height = height;
     }
+    with(width = this.width, height = this.height) {
+        if (width !== this.width || height !== this.height) {
+            return new Dimension(width, height);
+        }
+        else {
+            return this;
+        }
+    }
+    static is(obj) {
+        return typeof obj === 'object' && typeof obj.height === 'number' && typeof obj.width === 'number';
+    }
+    static lift(obj) {
+        if (obj instanceof Dimension) {
+            return obj;
+        }
+        else {
+            return new Dimension(obj.width, obj.height);
+        }
+    }
+    static equals(a, b) {
+        if (a === b) {
+            return true;
+        }
+        if (!a || !b) {
+            return false;
+        }
+        return a.width === b.width && a.height === b.height;
+    }
 }
 export function getTopLeftOffset(element) {
     // Adapted from WinJS.Utilities.getPosition
@@ -409,6 +381,14 @@ export function getTopLeftOffset(element) {
         top: top
     };
 }
+export function size(element, width, height) {
+    if (typeof width === 'number') {
+        element.style.width = `${width}px`;
+    }
+    if (typeof height === 'number') {
+        element.style.height = `${height}px`;
+    }
+}
 /**
  * Returns the position of a dom node relative to the entire page.
  */
@@ -477,12 +457,12 @@ export function isAncestor(testChild, testAncestor) {
 }
 export function findParentWithClass(node, clazz, stopAtClazzOrNode) {
     while (node && node.nodeType === node.ELEMENT_NODE) {
-        if (hasClass(node, clazz)) {
+        if (node.classList.contains(clazz)) {
             return node;
         }
         if (stopAtClazzOrNode) {
             if (typeof stopAtClazzOrNode === 'string') {
-                if (hasClass(node, stopAtClazzOrNode)) {
+                if (node.classList.contains(stopAtClazzOrNode)) {
                     return null;
                 }
             }
@@ -537,11 +517,12 @@ function getSharedStyleSheet() {
     return _sharedStyleSheet;
 }
 function getDynamicStyleSheetRules(style) {
-    if (style && style.sheet && style.sheet.rules) {
+    var _a, _b;
+    if ((_a = style === null || style === void 0 ? void 0 : style.sheet) === null || _a === void 0 ? void 0 : _a.rules) {
         // Chrome, IE
         return style.sheet.rules;
     }
-    if (style && style.sheet && style.sheet.cssRules) {
+    if ((_b = style === null || style === void 0 ? void 0 : style.sheet) === null || _b === void 0 ? void 0 : _b.cssRules) {
         // FF
         return style.sheet.cssRules;
     }
@@ -587,7 +568,7 @@ export const EventType = {
     MOUSE_OUT: 'mouseout',
     MOUSE_ENTER: 'mouseenter',
     MOUSE_LEAVE: 'mouseleave',
-    MOUSE_WHEEL: browser.isEdge ? 'mousewheel' : 'wheel',
+    MOUSE_WHEEL: 'wheel',
     POINTER_UP: 'pointerup',
     POINTER_DOWN: 'pointerdown',
     POINTER_MOVE: 'pointermove',
@@ -715,22 +696,19 @@ export function trackFocus(element) {
     return new FocusTracker(element);
 }
 export function append(parent, ...children) {
-    children.forEach(child => parent.appendChild(child));
-    return children[children.length - 1];
+    parent.append(...children);
+    if (children.length === 1 && typeof children[0] !== 'string') {
+        return children[0];
+    }
 }
-const SELECTOR_REGEX = /([\w\-]+)?(#([\w\-]+))?((\.([\w\-]+))*)/;
+/**
+ * Removes all children from `parent` and appends `children`
+ */
 export function reset(parent, ...children) {
     parent.innerText = '';
-    coalesce(children)
-        .forEach(child => {
-        if (child instanceof Node) {
-            parent.appendChild(child);
-        }
-        else {
-            parent.appendChild(document.createTextNode(child));
-        }
-    });
+    append(parent, ...children);
 }
+const SELECTOR_REGEX = /([\w\-]+)?(#([\w\-]+))?((\.([\w\-]+))*)/;
 export var Namespace;
 (function (Namespace) {
     Namespace["HTML"] = "http://www.w3.org/1999/xhtml";
@@ -773,15 +751,7 @@ function _$(namespace, description, attrs, ...children) {
             result.setAttribute(name, value);
         }
     });
-    coalesce(children)
-        .forEach(child => {
-        if (child instanceof Node) {
-            result.appendChild(child);
-        }
-        else {
-            result.appendChild(document.createTextNode(child));
-        }
-    });
+    result.append(...children);
     return result;
 }
 export function $(description, attrs, ...children) {
@@ -802,31 +772,6 @@ export function hide(...elements) {
         element.setAttribute('aria-hidden', 'true');
     }
 }
-function findParentWithAttribute(node, attribute) {
-    while (node && node.nodeType === node.ELEMENT_NODE) {
-        if (node instanceof HTMLElement && node.hasAttribute(attribute)) {
-            return node;
-        }
-        node = node.parentNode;
-    }
-    return null;
-}
-export function removeTabIndexAndUpdateFocus(node) {
-    if (!node || !node.hasAttribute('tabIndex')) {
-        return;
-    }
-    // If we are the currently focused element and tabIndex is removed,
-    // standard DOM behavior is to move focus to the <body> element. We
-    // typically never want that, rather put focus to the closest element
-    // in the hierarchy of the parent DOM nodes.
-    if (document.activeElement === node) {
-        let parentFocusable = findParentWithAttribute(node.parentElement, 'tabIndex');
-        if (parentFocusable) {
-            parentFocusable.focus();
-        }
-    }
-    node.removeAttribute('tabindex');
-}
 export function getElementsByTagName(tag) {
     return Array.prototype.slice.call(document.getElementsByTagName(tag), 0);
 }
@@ -843,25 +788,24 @@ export function computeScreenAwareSize(cssPx) {
     return Math.max(1, Math.floor(screenPx)) / window.devicePixelRatio;
 }
 /**
- * See https://github.com/Microsoft/monaco-editor/issues/601
+ * Open safely a new window. This is the best way to do so, but you cannot tell
+ * if the window was opened or if it was blocked by the brower's popup blocker.
+ * If you want to tell if the browser blocked the new window, use `windowOpenNoOpenerWithSuccess`.
+ *
+ * See https://github.com/microsoft/monaco-editor/issues/601
  * To protect against malicious code in the linked site, particularly phishing attempts,
  * the window.opener should be set to null to prevent the linked site from having access
  * to change the location of the current page.
  * See https://mathiasbynens.github.io/rel-noopener/
  */
 export function windowOpenNoOpener(url) {
-    if (platform.isNative || browser.isEdgeWebView) {
-        // In VSCode, window.open() always returns null...
-        // The same is true for a WebView (see https://github.com/Microsoft/monaco-editor/issues/628)
-        window.open(url);
-    }
-    else {
-        let newTab = window.open();
-        if (newTab) {
-            newTab.opener = null;
-            newTab.location.href = url;
-        }
-    }
+    // By using 'noopener' in the `windowFeatures` argument, the newly created window will
+    // not be able to use `window.opener` to reach back to the current page.
+    // See https://stackoverflow.com/a/46958731
+    // See https://developer.mozilla.org/en-US/docs/Web/API/Window/open#noopener
+    // However, this also doesn't allow us to realize if the browser blocked
+    // the creation of the window.
+    window.open(url, '_blank', 'noopener');
 }
 export function animate(fn) {
     const step = () => {
@@ -872,15 +816,6 @@ export function animate(fn) {
     return toDisposable(() => stepDisposable.dispose());
 }
 RemoteAuthorities.setPreferredWebSchema(/^https:/.test(window.location.href) ? 'https' : 'http');
-export function asDomUri(uri) {
-    if (!uri) {
-        return uri;
-    }
-    if (Schemas.vscodeRemote === uri.scheme) {
-        return RemoteAuthorities.rewrite(uri);
-    }
-    return uri;
-}
 /**
  * returns url('...')
  */
@@ -888,5 +823,140 @@ export function asCSSUrl(uri) {
     if (!uri) {
         return `url('')`;
     }
-    return `url('${asDomUri(uri).toString(true).replace(/'/g, '%27')}')`;
+    return `url('${FileAccess.asBrowserUri(uri).toString(true).replace(/'/g, '%27')}')`;
+}
+export function asCSSPropertyValue(value) {
+    return `'${value.replace(/'/g, '%27')}'`;
+}
+export class ModifierKeyEmitter extends Emitter {
+    constructor() {
+        super();
+        this._subscriptions = new DisposableStore();
+        this._keyStatus = {
+            altKey: false,
+            shiftKey: false,
+            ctrlKey: false,
+            metaKey: false
+        };
+        this._subscriptions.add(domEvent(window, 'keydown', true)(e => {
+            if (e.defaultPrevented) {
+                return;
+            }
+            const event = new StandardKeyboardEvent(e);
+            // If Alt-key keydown event is repeated, ignore it #112347
+            // Only known to be necessary for Alt-Key at the moment #115810
+            if (event.keyCode === 6 /* Alt */ && e.repeat) {
+                return;
+            }
+            if (e.altKey && !this._keyStatus.altKey) {
+                this._keyStatus.lastKeyPressed = 'alt';
+            }
+            else if (e.ctrlKey && !this._keyStatus.ctrlKey) {
+                this._keyStatus.lastKeyPressed = 'ctrl';
+            }
+            else if (e.metaKey && !this._keyStatus.metaKey) {
+                this._keyStatus.lastKeyPressed = 'meta';
+            }
+            else if (e.shiftKey && !this._keyStatus.shiftKey) {
+                this._keyStatus.lastKeyPressed = 'shift';
+            }
+            else if (event.keyCode !== 6 /* Alt */) {
+                this._keyStatus.lastKeyPressed = undefined;
+            }
+            else {
+                return;
+            }
+            this._keyStatus.altKey = e.altKey;
+            this._keyStatus.ctrlKey = e.ctrlKey;
+            this._keyStatus.metaKey = e.metaKey;
+            this._keyStatus.shiftKey = e.shiftKey;
+            if (this._keyStatus.lastKeyPressed) {
+                this._keyStatus.event = e;
+                this.fire(this._keyStatus);
+            }
+        }));
+        this._subscriptions.add(domEvent(window, 'keyup', true)(e => {
+            if (e.defaultPrevented) {
+                return;
+            }
+            if (!e.altKey && this._keyStatus.altKey) {
+                this._keyStatus.lastKeyReleased = 'alt';
+            }
+            else if (!e.ctrlKey && this._keyStatus.ctrlKey) {
+                this._keyStatus.lastKeyReleased = 'ctrl';
+            }
+            else if (!e.metaKey && this._keyStatus.metaKey) {
+                this._keyStatus.lastKeyReleased = 'meta';
+            }
+            else if (!e.shiftKey && this._keyStatus.shiftKey) {
+                this._keyStatus.lastKeyReleased = 'shift';
+            }
+            else {
+                this._keyStatus.lastKeyReleased = undefined;
+            }
+            if (this._keyStatus.lastKeyPressed !== this._keyStatus.lastKeyReleased) {
+                this._keyStatus.lastKeyPressed = undefined;
+            }
+            this._keyStatus.altKey = e.altKey;
+            this._keyStatus.ctrlKey = e.ctrlKey;
+            this._keyStatus.metaKey = e.metaKey;
+            this._keyStatus.shiftKey = e.shiftKey;
+            if (this._keyStatus.lastKeyReleased) {
+                this._keyStatus.event = e;
+                this.fire(this._keyStatus);
+            }
+        }));
+        this._subscriptions.add(domEvent(document.body, 'mousedown', true)(e => {
+            this._keyStatus.lastKeyPressed = undefined;
+        }));
+        this._subscriptions.add(domEvent(document.body, 'mouseup', true)(e => {
+            this._keyStatus.lastKeyPressed = undefined;
+        }));
+        this._subscriptions.add(domEvent(document.body, 'mousemove', true)(e => {
+            if (e.buttons) {
+                this._keyStatus.lastKeyPressed = undefined;
+            }
+        }));
+        this._subscriptions.add(domEvent(window, 'blur')(e => {
+            this.resetKeyStatus();
+        }));
+    }
+    get keyStatus() {
+        return this._keyStatus;
+    }
+    /**
+     * Allows to explicitly reset the key status based on more knowledge (#109062)
+     */
+    resetKeyStatus() {
+        this.doResetKeyStatus();
+        this.fire(this._keyStatus);
+    }
+    doResetKeyStatus() {
+        this._keyStatus = {
+            altKey: false,
+            shiftKey: false,
+            ctrlKey: false,
+            metaKey: false
+        };
+    }
+    static getInstance() {
+        if (!ModifierKeyEmitter.instance) {
+            ModifierKeyEmitter.instance = new ModifierKeyEmitter();
+        }
+        return ModifierKeyEmitter.instance;
+    }
+    dispose() {
+        super.dispose();
+        this._subscriptions.dispose();
+    }
+}
+export function addMatchMediaChangeListener(query, callback) {
+    const mediaQueryList = window.matchMedia(query);
+    if (typeof mediaQueryList.addEventListener === 'function') {
+        mediaQueryList.addEventListener('change', callback);
+    }
+    else {
+        // Safari 13.x
+        mediaQueryList.addListener(callback);
+    }
 }
