@@ -2,10 +2,9 @@
  *  Copyright (c) Microsoft Corporation. All rights reserved.
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
+var _a, _b;
 import { URI } from './uri.js';
-import { compareSubstringIgnoreCase, compare, compareSubstring } from './strings.js';
-import { Schemas } from './network.js';
-import { isLinux } from './platform.js';
+import { compareSubstringIgnoreCase, compare, compareSubstring, compareIgnoreCase } from './strings.js';
 export class StringIterator {
     constructor() {
         this._value = '';
@@ -32,6 +31,48 @@ export class StringIterator {
         return this._value[this._pos];
     }
 }
+export class ConfigKeysIterator {
+    constructor(_caseSensitive = true) {
+        this._caseSensitive = _caseSensitive;
+    }
+    reset(key) {
+        this._value = key;
+        this._from = 0;
+        this._to = 0;
+        return this.next();
+    }
+    hasNext() {
+        return this._to < this._value.length;
+    }
+    next() {
+        // this._data = key.split(/[\\/]/).filter(s => !!s);
+        this._from = this._to;
+        let justSeps = true;
+        for (; this._to < this._value.length; this._to++) {
+            const ch = this._value.charCodeAt(this._to);
+            if (ch === 46 /* Period */) {
+                if (justSeps) {
+                    this._from++;
+                }
+                else {
+                    break;
+                }
+            }
+            else {
+                justSeps = false;
+            }
+        }
+        return this;
+    }
+    cmp(a) {
+        return this._caseSensitive
+            ? compareSubstring(a, this._value, 0, a.length, this._from, this._to)
+            : compareSubstringIgnoreCase(a, this._value, 0, a.length, this._from, this._to);
+    }
+    value() {
+        return this._value.substring(this._from, this._to);
+    }
+}
 export class PathIterator {
     constructor(_splitOnBackslash = true, _caseSensitive = true) {
         this._splitOnBackslash = _splitOnBackslash;
@@ -76,7 +117,8 @@ export class PathIterator {
     }
 }
 export class UriIterator {
-    constructor() {
+    constructor(_ignorePathCasing) {
+        this._ignorePathCasing = _ignorePathCasing;
         this._states = [];
         this._stateIdx = 0;
     }
@@ -90,10 +132,7 @@ export class UriIterator {
             this._states.push(2 /* Authority */);
         }
         if (this._value.path) {
-            //todo@jrieken the case-sensitive logic is copied form `resources.ts#hasToIgnoreCase`
-            // which cannot be used because it depends on this
-            const caseSensitive = key.scheme === Schemas.file && isLinux;
-            this._pathIterator = new PathIterator(false, caseSensitive);
+            this._pathIterator = new PathIterator(false, !this._ignorePathCasing(key));
             this._pathIterator.reset(key.path);
             if (this._pathIterator.value()) {
                 this._states.push(3 /* Path */);
@@ -123,10 +162,10 @@ export class UriIterator {
     }
     cmp(a) {
         if (this._states[this._stateIdx] === 1 /* Scheme */) {
-            return compare(a, this._value.scheme);
+            return compareIgnoreCase(a, this._value.scheme);
         }
         else if (this._states[this._stateIdx] === 2 /* Authority */) {
-            return compareSubstringIgnoreCase(a, this._value.authority);
+            return compareIgnoreCase(a, this._value.authority);
         }
         else if (this._states[this._stateIdx] === 3 /* Path */) {
             return this._pathIterator.cmp(a);
@@ -159,17 +198,23 @@ export class UriIterator {
     }
 }
 class TernarySearchTreeNode {
+    isEmpty() {
+        return !this.left && !this.mid && !this.right && !this.value;
+    }
 }
 export class TernarySearchTree {
     constructor(segments) {
         this._iter = segments;
     }
-    static forUris() {
-        return new TernarySearchTree(new UriIterator());
+    static forUris(ignorePathCasing = () => false) {
+        return new TernarySearchTree(new UriIterator(ignorePathCasing));
     }
     static forStrings() {
         return new TernarySearchTree(new StringIterator());
     }
+    static forConfigKeys() {
+        return new TernarySearchTree(new ConfigKeysIterator());
+    }
     clear() {
         this._root = undefined;
     }
@@ -218,6 +263,10 @@ export class TernarySearchTree {
         return oldElement;
     }
     get(key) {
+        var _c;
+        return (_c = this._getNode(key)) === null || _c === void 0 ? void 0 : _c.value;
+    }
+    _getNode(key) {
         const iter = this._iter.reset(key);
         let node = this._root;
         while (node) {
@@ -239,7 +288,71 @@ export class TernarySearchTree {
                 break;
             }
         }
-        return node ? node.value : undefined;
+        return node;
+    }
+    has(key) {
+        const node = this._getNode(key);
+        return !((node === null || node === void 0 ? void 0 : node.value) === undefined && (node === null || node === void 0 ? void 0 : node.mid) === undefined);
+    }
+    delete(key) {
+        return this._delete(key, false);
+    }
+    deleteSuperstr(key) {
+        return this._delete(key, true);
+    }
+    _delete(key, superStr) {
+        const iter = this._iter.reset(key);
+        const stack = [];
+        let node = this._root;
+        // find and unset node
+        while (node) {
+            const val = iter.cmp(node.segment);
+            if (val > 0) {
+                // left
+                stack.push([1, node]);
+                node = node.left;
+            }
+            else if (val < 0) {
+                // right
+                stack.push([-1, node]);
+                node = node.right;
+            }
+            else if (iter.hasNext()) {
+                // mid
+                iter.next();
+                stack.push([0, node]);
+                node = node.mid;
+            }
+            else {
+                if (superStr) {
+                    // remove children
+                    node.left = undefined;
+                    node.mid = undefined;
+                    node.right = undefined;
+                }
+                else {
+                    // remove element
+                    node.value = undefined;
+                }
+                // clean up empty nodes
+                while (stack.length > 0 && node.isEmpty()) {
+                    let [dir, parent] = stack.pop();
+                    switch (dir) {
+                        case 1:
+                            parent.left = undefined;
+                            break;
+                        case 0:
+                            parent.mid = undefined;
+                            break;
+                        case -1:
+                            parent.right = undefined;
+                            break;
+                    }
+                    node = parent;
+                }
+                break;
+            }
+        }
     }
     findSubstr(key) {
         const iter = this._iter.reset(key);
@@ -267,28 +380,67 @@ export class TernarySearchTree {
         }
         return node && node.value || candidate;
     }
-    forEach(callback) {
-        this._forEach(this._root, callback);
+    findSuperstr(key) {
+        const iter = this._iter.reset(key);
+        let node = this._root;
+        while (node) {
+            const val = iter.cmp(node.segment);
+            if (val > 0) {
+                // left
+                node = node.left;
+            }
+            else if (val < 0) {
+                // right
+                node = node.right;
+            }
+            else if (iter.hasNext()) {
+                // mid
+                iter.next();
+                node = node.mid;
+            }
+            else {
+                // collect
+                if (!node.mid) {
+                    return undefined;
+                }
+                else {
+                    return this._entries(node.mid);
+                }
+            }
+        }
+        return undefined;
     }
-    _forEach(node, callback) {
+    forEach(callback) {
+        for (const [key, value] of this) {
+            callback(value, key);
+        }
+    }
+    *[Symbol.iterator]() {
+        yield* this._entries(this._root);
+    }
+    *_entries(node, i = 0) {
+        if (i > 5000) {
+            console.log('potential CYCLE detected', new Error().stack);
+            return;
+        }
         if (node) {
             // left
-            this._forEach(node.left, callback);
+            yield* this._entries(node.left, i++);
             // node
             if (node.value) {
                 // callback(node.value, this._iter.join(parts));
-                callback(node.value, node.key);
+                yield [node.key, node.value];
             }
             // mid
-            this._forEach(node.mid, callback);
+            yield* this._entries(node.mid, i++);
             // right
-            this._forEach(node.right, callback);
+            yield* this._entries(node.right, i++);
         }
     }
 }
 export class ResourceMap {
     constructor(mapOrKeyFn, toKey) {
-        this[Symbol.toStringTag] = 'ResourceMap';
+        this[_a] = 'ResourceMap';
         if (mapOrKeyFn instanceof ResourceMap) {
             this.map = new Map(mapOrKeyFn.map);
             this.toKey = toKey !== null && toKey !== void 0 ? toKey : ResourceMap.defaultToKey;
@@ -338,7 +490,7 @@ export class ResourceMap {
             yield [URI.parse(tuple[0]), tuple[1]];
         }
     }
-    *[Symbol.iterator]() {
+    *[(_a = Symbol.toStringTag, Symbol.iterator)]() {
         for (let item of this.map) {
             yield [URI.parse(item[0]), item[1]];
         }
@@ -347,7 +499,7 @@ export class ResourceMap {
 ResourceMap.defaultToKey = (resource) => resource.toString();
 export class LinkedMap {
     constructor() {
-        this[Symbol.toStringTag] = 'LinkedMap';
+        this[_b] = 'LinkedMap';
         this._map = new Map();
         this._head = undefined;
         this._tail = undefined;
@@ -368,12 +520,12 @@ export class LinkedMap {
         return this._size;
     }
     get first() {
-        var _a;
-        return (_a = this._head) === null || _a === void 0 ? void 0 : _a.value;
+        var _c;
+        return (_c = this._head) === null || _c === void 0 ? void 0 : _c.value;
     }
     get last() {
-        var _a;
-        return (_a = this._tail) === null || _a === void 0 ? void 0 : _a.value;
+        var _c;
+        return (_c = this._tail) === null || _c === void 0 ? void 0 : _c.value;
     }
     has(key) {
         return this._map.has(key);
@@ -531,7 +683,7 @@ export class LinkedMap {
         };
         return iterator;
     }
-    [Symbol.iterator]() {
+    [(_b = Symbol.toStringTag, Symbol.iterator)]() {
         return this.entries();
     }
     trimOld(newSize) {
@@ -592,7 +744,7 @@ export class LinkedMap {
             this._tail = undefined;
         }
         else if (item === this._head) {
-            // This can only happend if size === 1 which is handle
+            // This can only happen if size === 1 which is handled
             // by the case above.
             if (!item.next) {
                 throw new Error('Invalid list');
@@ -601,7 +753,7 @@ export class LinkedMap {
             this._head = item.next;
         }
         else if (item === this._tail) {
-            // This can only happend if size === 1 which is handle
+            // This can only happen if size === 1 which is handled
             // by the case above.
             if (!item.previous) {
                 throw new Error('Invalid list');
