@@ -7,6 +7,6 @@ registerLanguage({
     id: 'yaml',
     extensions: ['.yaml', '.yml'],
     aliases: ['YAML', 'yaml', 'YML', 'yml'],
-    mimetypes: ['application/x-yaml'],
+    mimetypes: ['application/x-yaml', 'text/x-yaml'],
     loader: function () { return import('./yaml.js'); }
 });
