@@ -9,7 +9,7 @@ import { RangeUtil } from './rangeUtil.js';
 import { HorizontalRange, VisibleRanges } from '../../../common/view/renderingContext.js';
 import { LineDecoration } from '../../../common/viewLayout/lineDecorations.js';
 import { CharacterMapping, RenderLineInput, renderViewLine, LineRange } from '../../../common/viewLayout/viewLineRenderer.js';
-import { HIGH_CONTRAST } from '../../../../platform/theme/common/themeService.js';
+import { ColorScheme } from '../../../../platform/theme/common/theme.js';
 import { EditorFontLigatures } from '../../../common/config/editorOptions.js';
 const canUseFastRenderedViewLine = (function () {
     if (platform.isNative) {
@@ -33,7 +33,6 @@ const canUseFastRenderedViewLine = (function () {
     return true;
 })();
 let monospaceAssumptionsAreValid = true;
-const alwaysRenderInlineSelection = (browser.isEdge);
 export class DomReadingContext {
     constructor(domNode, endNode) {
         this._domNode = domNode;
@@ -53,18 +52,18 @@ export class ViewLineOptions {
     constructor(config, themeType) {
         this.themeType = themeType;
         const options = config.options;
-        const fontInfo = options.get(36 /* fontInfo */);
-        this.renderWhitespace = options.get(80 /* renderWhitespace */);
-        this.renderControlCharacters = options.get(74 /* renderControlCharacters */);
+        const fontInfo = options.get(40 /* fontInfo */);
+        this.renderWhitespace = options.get(86 /* renderWhitespace */);
+        this.renderControlCharacters = options.get(80 /* renderControlCharacters */);
         this.spaceWidth = fontInfo.spaceWidth;
         this.middotWidth = fontInfo.middotWidth;
         this.wsmiddotWidth = fontInfo.wsmiddotWidth;
         this.useMonospaceOptimizations = (fontInfo.isMonospace
-            && !options.get(24 /* disableMonospaceOptimizations */));
+            && !options.get(27 /* disableMonospaceOptimizations */));
         this.canUseHalfwidthRightwardsArrow = fontInfo.canUseHalfwidthRightwardsArrow;
-        this.lineHeight = options.get(51 /* lineHeight */);
-        this.stopRenderingLineAfter = options.get(95 /* stopRenderingLineAfter */);
-        this.fontLigatures = options.get(37 /* fontLigatures */);
+        this.lineHeight = options.get(56 /* lineHeight */);
+        this.stopRenderingLineAfter = options.get(103 /* stopRenderingLineAfter */);
+        this.fontLigatures = options.get(41 /* fontLigatures */);
     }
     equals(other) {
         return (this.themeType === other.themeType
@@ -115,7 +114,7 @@ export class ViewLine {
         this._options = newOptions;
     }
     onSelectionChanged() {
-        if (alwaysRenderInlineSelection || this._options.themeType === HIGH_CONTRAST || this._options.renderWhitespace === 'selection') {
+        if (this._options.themeType === ColorScheme.HIGH_CONTRAST || this._options.renderWhitespace === 'selection') {
             this._isMaybeInvalid = true;
             return true;
         }
@@ -132,7 +131,7 @@ export class ViewLine {
         const actualInlineDecorations = LineDecoration.filter(lineData.inlineDecorations, lineNumber, lineData.minColumn, lineData.maxColumn);
         // Only send selection information when needed for rendering whitespace
         let selectionsOnLine = null;
-        if (alwaysRenderInlineSelection || options.themeType === HIGH_CONTRAST || this._options.renderWhitespace === 'selection') {
+        if (options.themeType === ColorScheme.HIGH_CONTRAST || this._options.renderWhitespace === 'selection') {
             const selections = viewportData.selections;
             for (const selection of selections) {
                 if (selection.endLineNumber < lineNumber || selection.startLineNumber > lineNumber) {
@@ -142,7 +141,7 @@ export class ViewLine {
                 const startColumn = (selection.startLineNumber === lineNumber ? selection.startColumn : lineData.minColumn);
                 const endColumn = (selection.endLineNumber === lineNumber ? selection.endColumn : lineData.maxColumn);
                 if (startColumn < endColumn) {
-                    if (options.themeType === HIGH_CONTRAST || this._options.renderWhitespace !== 'selection') {
+                    if (options.themeType === ColorScheme.HIGH_CONTRAST || this._options.renderWhitespace !== 'selection') {
                         actualInlineDecorations.push(new LineDecoration(startColumn, endColumn, 'inline-selected-text', 0 /* Regular */));
                     }
                     else {
@@ -178,7 +177,7 @@ export class ViewLine {
                 // rounding errors add up to an observable large number...
                 // ---
                 // Also see another example of rounding errors on Windows in
-                // https://github.com/Microsoft/vscode/issues/33178
+                // https://github.com/microsoft/vscode/issues/33178
                 renderedViewLine = new FastRenderedViewLine(this._renderedViewLine ? this._renderedViewLine.domNode : null, renderLineInput, output.characterMapping);
             }
         }
