@@ -8,49 +8,7 @@ import { Range } from '../core/range.js';
 import { ModelDecorationOptions } from '../model/textModel.js';
 import * as viewEvents from '../view/viewEvents.js';
 import { PrefixSumIndexOfResult } from './prefixSumComputer.js';
-import { ViewLineData } from './viewModel.js';
-export class OutputPosition {
-    constructor(outputLineIndex, outputOffset) {
-        this.outputLineIndex = outputLineIndex;
-        this.outputOffset = outputOffset;
-    }
-}
-export class LineBreakData {
-    constructor(breakOffsets, breakOffsetsVisibleColumn, wrappedTextIndentLength) {
-        this.breakOffsets = breakOffsets;
-        this.breakOffsetsVisibleColumn = breakOffsetsVisibleColumn;
-        this.wrappedTextIndentLength = wrappedTextIndentLength;
-    }
-    static getInputOffsetOfOutputPosition(breakOffsets, outputLineIndex, outputOffset) {
-        if (outputLineIndex === 0) {
-            return outputOffset;
-        }
-        else {
-            return breakOffsets[outputLineIndex - 1] + outputOffset;
-        }
-    }
-    static getOutputPositionOfInputOffset(breakOffsets, inputOffset) {
-        let low = 0;
-        let high = breakOffsets.length - 1;
-        let mid = 0;
-        let midStart = 0;
-        while (low <= high) {
-            mid = low + ((high - low) / 2) | 0;
-            const midStop = breakOffsets[mid];
-            midStart = mid > 0 ? breakOffsets[mid - 1] : 0;
-            if (inputOffset < midStart) {
-                high = mid - 1;
-            }
-            else if (inputOffset >= midStop) {
-                low = mid + 1;
-            }
-            else {
-                break;
-            }
-        }
-        return new OutputPosition(mid, inputOffset - midStart);
-    }
-}
+import { LineBreakData, ViewLineData } from './viewModel.js';
 export class CoordinatesConverter {
     constructor(lines) {
         this._lines = lines;
@@ -78,6 +36,9 @@ export class CoordinatesConverter {
     modelPositionIsVisible(modelPosition) {
         return this._lines.modelPositionIsVisible(modelPosition.lineNumber, modelPosition.column);
     }
+    getModelLineViewLineCount(modelLineNumber) {
+        return this._lines.getModelLineViewLineCount(modelLineNumber);
+    }
 }
 class LineNumberMapper {
     constructor(viewLineCounts) {
@@ -292,6 +253,13 @@ export class SplitLinesCollection {
         }
         return this.lines[modelLineNumber - 1].isVisible();
     }
+    getModelLineViewLineCount(modelLineNumber) {
+        if (modelLineNumber < 1 || modelLineNumber > this.lines.length) {
+            // invalid arguments
+            return 1;
+        }
+        return this.lines[modelLineNumber - 1].getViewLineCount();
+    }
     setTabSize(newTabSize) {
         if (this.tabSize === newTabSize) {
             return false;
@@ -350,15 +318,8 @@ export class SplitLinesCollection {
             // We don't want to apply stale change events on top of a newer read model state.
             return null;
         }
-        let hiddenAreas = this.getHiddenAreas();
-        let isInHiddenArea = false;
-        let testPosition = new Position(fromLineNumber, 1);
-        for (const hiddenArea of hiddenAreas) {
-            if (hiddenArea.containsPosition(testPosition)) {
-                isInHiddenArea = true;
-                break;
-            }
-        }
+        // cannot use this.getHiddenAreas() because those decorations have already seen the effect of this model change
+        const isInHiddenArea = (fromLineNumber > 2 && !this.lines[fromLineNumber - 2].isVisible());
         let outputFromLineNumber = (fromLineNumber === 1 ? 1 : this.prefixSumComputer.getAccumulatedValue(fromLineNumber - 2) + 1);
         let totalOutputLineCount = 0;
         let insertLines = [];
@@ -756,6 +717,26 @@ export class SplitLinesCollection {
         }
         return finalResult;
     }
+    normalizePosition(position, affinity) {
+        const viewLineNumber = this._toValidViewLineNumber(position.lineNumber);
+        const r = this.prefixSumComputer.getIndexOf(viewLineNumber - 1);
+        const lineIndex = r.index;
+        const remainder = r.remainder;
+        return this.lines[lineIndex].normalizePosition(this.model, lineIndex + 1, remainder, position, affinity);
+    }
+    getLineIndentColumn(lineNumber) {
+        const viewLineNumber = this._toValidViewLineNumber(lineNumber);
+        const r = this.prefixSumComputer.getIndexOf(viewLineNumber - 1);
+        const lineIndex = r.index;
+        const remainder = r.remainder;
+        if (remainder === 0) {
+            return this.model.getLineIndentColumn(lineIndex + 1);
+        }
+        // wrapped lines have no indentation.
+        // We deliberately don't handle the case that indentation is wrapped
+        // to avoid two view lines reporting indentation for the very same model line.
+        return 0;
+    }
 }
 class VisibleIdentitySplitLine {
     constructor() { }
@@ -807,6 +788,9 @@ class VisibleIdentitySplitLine {
     getViewLineNumberOfModelPosition(deltaLineNumber, _inputColumn) {
         return deltaLineNumber;
     }
+    normalizePosition(model, modelLineNumber, outputLineIndex, outputPosition, affinity) {
+        return outputPosition;
+    }
 }
 VisibleIdentitySplitLine.INSTANCE = new VisibleIdentitySplitLine();
 class InvisibleIdentitySplitLine {
@@ -853,6 +837,9 @@ class InvisibleIdentitySplitLine {
     getViewLineNumberOfModelPosition(_deltaLineNumber, _inputColumn) {
         throw new Error('Not supported');
     }
+    normalizePosition(model, modelLineNumber, outputLineIndex, outputPosition, affinity) {
+        throw new Error('Not supported');
+    }
 }
 InvisibleIdentitySplitLine.INSTANCE = new InvisibleIdentitySplitLine();
 export class SplitLine {
@@ -918,6 +905,9 @@ export class SplitLine {
         if (!this._isVisible) {
             throw new Error('Not supported');
         }
+        return this._getViewLineMinColumn(outputLineIndex);
+    }
+    _getViewLineMinColumn(outputLineIndex) {
         if (outputLineIndex > 0) {
             return this._lineBreakData.wrappedTextIndentLength + 1;
         }
@@ -927,7 +917,7 @@ export class SplitLine {
         if (!this._isVisible) {
             throw new Error('Not supported');
         }
-        return this.getViewLineContent(model, modelLineNumber, outputLineIndex).length + 1;
+        return this.getViewLineLength(model, modelLineNumber, outputLineIndex) + 1;
     }
     getViewLineData(model, modelLineNumber, outputLineIndex) {
         if (!this._isVisible) {
@@ -1003,6 +993,20 @@ export class SplitLine {
         const r = LineBreakData.getOutputPositionOfInputOffset(this._lineBreakData.breakOffsets, inputColumn - 1);
         return (deltaLineNumber + r.outputLineIndex);
     }
+    normalizePosition(model, modelLineNumber, outputLineIndex, outputPosition, affinity) {
+        if (affinity === 0 /* Left */) {
+            if (outputLineIndex > 0 && outputPosition.column === this._getViewLineMinColumn(outputLineIndex)) {
+                return new Position(outputPosition.lineNumber - 1, this.getViewLineMaxColumn(model, modelLineNumber, outputLineIndex - 1));
+            }
+        }
+        else if (affinity === 1 /* Right */) {
+            const maxOutputLineIndex = this.getViewLineCount() - 1;
+            if (outputLineIndex < maxOutputLineIndex && outputPosition.column === this.getViewLineMaxColumn(model, modelLineNumber, outputLineIndex)) {
+                return new Position(outputPosition.lineNumber + 1, this._getViewLineMinColumn(outputLineIndex + 1));
+            }
+        }
+        return outputPosition;
+    }
 }
 let _spaces = [''];
 function spaces(count) {
@@ -1066,6 +1070,9 @@ export class IdentityCoordinatesConverter {
         }
         return true;
     }
+    getModelLineViewLineCount(modelLineNumber) {
+        return 1;
+    }
 }
 export class IdentityLinesCollection {
     constructor(model) {
@@ -1180,6 +1187,12 @@ export class IdentityLinesCollection {
     getDecorationsInRange(range, ownerId, filterOutValidation) {
         return this.model.getDecorationsInRange(range, ownerId, filterOutValidation);
     }
+    normalizePosition(position, affinity) {
+        return this.model.normalizePosition(position, affinity);
+    }
+    getLineIndentColumn(lineNumber) {
+        return this.model.getLineIndentColumn(lineNumber);
+    }
 }
 class OverviewRulerDecorations {
     constructor() {
