@@ -42,10 +42,10 @@ export class ViewModel extends Disposable {
         }
         else {
             const options = this._configuration.options;
-            const fontInfo = options.get(36 /* fontInfo */);
-            const wrappingStrategy = options.get(112 /* wrappingStrategy */);
-            const wrappingInfo = options.get(118 /* wrappingInfo */);
-            const wrappingIndent = options.get(111 /* wrappingIndent */);
+            const fontInfo = options.get(40 /* fontInfo */);
+            const wrappingStrategy = options.get(122 /* wrappingStrategy */);
+            const wrappingInfo = options.get(129 /* wrappingInfo */);
+            const wrappingIndent = options.get(121 /* wrappingIndent */);
             this._lines = new SplitLinesCollection(this.model, domLineBreaksComputerFactory, monospaceLineBreaksComputerFactory, fontInfo, this.model.getOptions().tabSize, wrappingStrategy, wrappingInfo.wrappingColumn, wrappingIndent);
         }
         this.coordinatesConverter = this._lines.createCoordinatesConverter();
@@ -87,6 +87,9 @@ export class ViewModel extends Disposable {
         this._viewportStartLineTrackedRange = this.model._setTrackedRange(this._viewportStartLineTrackedRange, null, 1 /* NeverGrowsWhenTypingAtEdges */);
         this._eventDispatcher.dispose();
     }
+    createLineBreaksComputer() {
+        return this._lines.createLineBreaksComputer();
+    }
     addViewEventHandler(eventHandler) {
         this._eventDispatcher.addViewEventHandler(eventHandler);
     }
@@ -108,6 +111,12 @@ export class ViewModel extends Disposable {
         this._eventDispatcher.emitSingleViewEvent(new viewEvents.ViewFocusChangedEvent(hasFocus));
         this._eventDispatcher.emitOutgoingEvent(new FocusChangedEvent(!hasFocus, hasFocus));
     }
+    onCompositionStart() {
+        this._eventDispatcher.emitSingleViewEvent(new viewEvents.ViewCompositionStartEvent());
+    }
+    onCompositionEnd() {
+        this._eventDispatcher.emitSingleViewEvent(new viewEvents.ViewCompositionEndEvent());
+    }
     onDidColorThemeChange() {
         this._eventDispatcher.emitSingleViewEvent(new viewEvents.ViewThemeChangedEvent());
     }
@@ -120,10 +129,10 @@ export class ViewModel extends Disposable {
         }
         let restorePreviousViewportStart = false;
         const options = this._configuration.options;
-        const fontInfo = options.get(36 /* fontInfo */);
-        const wrappingStrategy = options.get(112 /* wrappingStrategy */);
-        const wrappingInfo = options.get(118 /* wrappingInfo */);
-        const wrappingIndent = options.get(111 /* wrappingIndent */);
+        const fontInfo = options.get(40 /* fontInfo */);
+        const wrappingStrategy = options.get(122 /* wrappingStrategy */);
+        const wrappingInfo = options.get(129 /* wrappingInfo */);
+        const wrappingIndent = options.get(121 /* wrappingIndent */);
         if (this._lines.setWrappingSettings(fontInfo, wrappingStrategy, wrappingInfo.wrappingColumn, wrappingIndent)) {
             eventsCollector.emitViewEvent(new viewEvents.ViewFlushedEvent());
             eventsCollector.emitViewEvent(new viewEvents.ViewLineMappingChangedEvent());
@@ -137,7 +146,7 @@ export class ViewModel extends Disposable {
             }
             this._updateConfigurationViewLineCount.schedule();
         }
-        if (e.hasChanged(72 /* readOnly */)) {
+        if (e.hasChanged(78 /* readOnly */)) {
             // Must read again all decorations due to readOnly filtering
             this._decorations.reset();
             eventsCollector.emitViewEvent(new viewEvents.ViewDecorationsChangedEvent(null));
@@ -337,8 +346,8 @@ export class ViewModel extends Disposable {
         this._updateConfigurationViewLineCount.schedule();
     }
     getVisibleRangesPlusViewportAboveBelow() {
-        const layoutInfo = this._configuration.options.get(117 /* layoutInfo */);
-        const lineHeight = this._configuration.options.get(51 /* lineHeight */);
+        const layoutInfo = this._configuration.options.get(128 /* layoutInfo */);
+        const lineHeight = this._configuration.options.get(56 /* lineHeight */);
         const linesAround = Math.max(20, Math.round(layoutInfo.height / lineHeight));
         const partialData = this.viewLayout.getLinesViewportData();
         const startViewLineNumber = Math.max(1, partialData.completelyVisibleStartLineNumber - linesAround);
@@ -619,9 +628,26 @@ export class ViewModel extends Disposable {
             const lineNumber = range.startLineNumber;
             range = new Range(lineNumber, this.model.getLineMinColumn(lineNumber), lineNumber, this.model.getLineMaxColumn(lineNumber));
         }
-        const fontInfo = this._configuration.options.get(36 /* fontInfo */);
+        const fontInfo = this._configuration.options.get(40 /* fontInfo */);
         const colorMap = this._getColorMap();
-        const fontFamily = fontInfo.fontFamily === EDITOR_FONT_DEFAULTS.fontFamily ? fontInfo.fontFamily : `'${fontInfo.fontFamily}', ${EDITOR_FONT_DEFAULTS.fontFamily}`;
+        const hasBadChars = (/[:;\\\/<>]/.test(fontInfo.fontFamily));
+        const useDefaultFontFamily = (hasBadChars || fontInfo.fontFamily === EDITOR_FONT_DEFAULTS.fontFamily);
+        let fontFamily;
+        if (useDefaultFontFamily) {
+            fontFamily = EDITOR_FONT_DEFAULTS.fontFamily;
+        }
+        else {
+            fontFamily = fontInfo.fontFamily;
+            fontFamily = fontFamily.replace(/"/g, '\'');
+            const hasQuotesOrIsList = /[,']/.test(fontFamily);
+            if (!hasQuotesOrIsList) {
+                const needsQuotes = /[+ ]/.test(fontFamily);
+                if (needsQuotes) {
+                    fontFamily = `'${fontFamily}'`;
+                }
+            }
+            fontFamily = `${fontFamily}, ${EDITOR_FONT_DEFAULTS.fontFamily}`;
+        }
         return {
             mode: languageId.language,
             html: (`<div style="`
@@ -689,6 +715,9 @@ export class ViewModel extends Disposable {
     getCursorColumnSelectData() {
         return this._cursor.getCursorColumnSelectData();
     }
+    getCursorAutoClosedCharacters() {
+        return this._cursor.getAutoClosedCharacters();
+    }
     setCursorColumnSelectData(columnSelectData) {
         this._cursor.setCursorColumnSelectData(columnSelectData);
     }
@@ -707,8 +736,8 @@ export class ViewModel extends Disposable {
     getPosition() {
         return this._cursor.getPrimaryCursorState().modelState.position;
     }
-    setSelections(source, selections) {
-        this._withViewEventsCollector(eventsCollector => this._cursor.setSelections(eventsCollector, source, selections));
+    setSelections(source, selections, reason = 0 /* NotSet */) {
+        this._withViewEventsCollector(eventsCollector => this._cursor.setSelections(eventsCollector, source, selections, reason));
     }
     saveCursorState() {
         return this._cursor.saveState();
@@ -738,8 +767,8 @@ export class ViewModel extends Disposable {
     type(text, source) {
         this._executeCursorEdit(eventsCollector => this._cursor.type(eventsCollector, text, source));
     }
-    replacePreviousChar(text, replaceCharCnt, source) {
-        this._executeCursorEdit(eventsCollector => this._cursor.replacePreviousChar(eventsCollector, text, replaceCharCnt, source));
+    compositionType(text, replacePrevCharCnt, replaceNextCharCnt, positionDelta, source) {
+        this._executeCursorEdit(eventsCollector => this._cursor.compositionType(eventsCollector, text, replacePrevCharCnt, replaceNextCharCnt, positionDelta, source));
     }
     paste(text, pasteOnNewLine, multicursorText, source) {
         this._executeCursorEdit(eventsCollector => this._cursor.paste(eventsCollector, text, pasteOnNewLine, multicursorText, source));
@@ -806,4 +835,14 @@ export class ViewModel extends Disposable {
             this._eventDispatcher.endEmitViewEvents();
         }
     }
+    normalizePosition(position, affinity) {
+        return this._lines.normalizePosition(position, affinity);
+    }
+    /**
+     * Gets the column at which indentation stops at a given line.
+     * @internal
+    */
+    getLineIndentColumn(lineNumber) {
+        return this._lines.getLineIndentColumn(lineNumber);
+    }
 }
