@@ -19,7 +19,7 @@ import { RunOnceScheduler, Delayer, createCancelablePromise } from '../../../bas
 import { KeyChord } from '../../../base/common/keyCodes.js';
 import { Disposable, DisposableStore } from '../../../base/common/lifecycle.js';
 import { registerEditorAction, registerEditorContribution, EditorAction, registerInstantiatedEditorAction } from '../../browser/editorExtensions.js';
-import { FoldingModel, setCollapseStateAtLevel, setCollapseStateLevelsDown, setCollapseStateLevelsUp, setCollapseStateForMatchingLines, setCollapseStateForType, toggleCollapseState, setCollapseStateUp } from './foldingModel.js';
+import { FoldingModel, setCollapseStateAtLevel, setCollapseStateLevelsDown, setCollapseStateLevelsUp, setCollapseStateForMatchingLines, setCollapseStateForType, setCollapseStateForRest, toggleCollapseState, setCollapseStateUp } from './foldingModel.js';
 import { FoldingDecorationProvider, foldingCollapsedIcon, foldingExpandedIcon } from './foldingDecorations.js';
 import { EditorContextKeys } from '../../common/editorContextKeys.js';
 import { HiddenRangeModel } from './hiddenRangeModel.js';
@@ -30,7 +30,7 @@ import { SyntaxRangeProvider, ID_SYNTAX_PROVIDER } from './syntaxRangeProvider.j
 import { InitializingRangeProvider, ID_INIT_PROVIDER } from './intializingRangeProvider.js';
 import { onUnexpectedError } from '../../../base/common/errors.js';
 import { RawContextKey, IContextKeyService } from '../../../platform/contextkey/common/contextkey.js';
-import { registerThemingParticipant } from '../../../platform/theme/common/themeService.js';
+import { registerThemingParticipant, ThemeIcon } from '../../../platform/theme/common/themeService.js';
 import { registerColor, editorSelectionBackground, transparent, iconForeground } from '../../../platform/theme/common/colorRegistry.js';
 const CONTEXT_FOLDING_ENABLED = new RawContextKey('foldingEnabled', false);
 let FoldingController = class FoldingController extends Disposable {
@@ -40,9 +40,10 @@ let FoldingController = class FoldingController extends Disposable {
         this.localToDispose = this._register(new DisposableStore());
         this.editor = editor;
         const options = this.editor.getOptions();
-        this._isEnabled = options.get(31 /* folding */);
-        this._useFoldingProviders = options.get(32 /* foldingStrategy */) !== 'indentation';
-        this._unfoldOnClickAfterEndOfLine = options.get(34 /* unfoldOnClickAfterEndOfLine */);
+        this._isEnabled = options.get(35 /* folding */);
+        this._useFoldingProviders = options.get(36 /* foldingStrategy */) !== 'indentation';
+        this._unfoldOnClickAfterEndOfLine = options.get(38 /* unfoldOnClickAfterEndOfLine */);
+        this._restoringViewState = false;
         this.foldingModel = null;
         this.hiddenRangeModel = null;
         this.rangeProvider = null;
@@ -53,29 +54,29 @@ let FoldingController = class FoldingController extends Disposable {
         this.cursorChangedScheduler = null;
         this.mouseDownInfo = null;
         this.foldingDecorationProvider = new FoldingDecorationProvider(editor);
-        this.foldingDecorationProvider.autoHideFoldingControls = options.get(91 /* showFoldingControls */) === 'mouseover';
-        this.foldingDecorationProvider.showFoldingHighlights = options.get(33 /* foldingHighlight */);
+        this.foldingDecorationProvider.autoHideFoldingControls = options.get(97 /* showFoldingControls */) === 'mouseover';
+        this.foldingDecorationProvider.showFoldingHighlights = options.get(37 /* foldingHighlight */);
         this.foldingEnabled = CONTEXT_FOLDING_ENABLED.bindTo(this.contextKeyService);
         this.foldingEnabled.set(this._isEnabled);
         this._register(this.editor.onDidChangeModel(() => this.onModelChanged()));
         this._register(this.editor.onDidChangeConfiguration((e) => {
-            if (e.hasChanged(31 /* folding */)) {
-                this._isEnabled = this.editor.getOptions().get(31 /* folding */);
+            if (e.hasChanged(35 /* folding */)) {
+                this._isEnabled = this.editor.getOptions().get(35 /* folding */);
                 this.foldingEnabled.set(this._isEnabled);
                 this.onModelChanged();
             }
-            if (e.hasChanged(91 /* showFoldingControls */) || e.hasChanged(33 /* foldingHighlight */)) {
+            if (e.hasChanged(97 /* showFoldingControls */) || e.hasChanged(37 /* foldingHighlight */)) {
                 const options = this.editor.getOptions();
-                this.foldingDecorationProvider.autoHideFoldingControls = options.get(91 /* showFoldingControls */) === 'mouseover';
-                this.foldingDecorationProvider.showFoldingHighlights = options.get(33 /* foldingHighlight */);
+                this.foldingDecorationProvider.autoHideFoldingControls = options.get(97 /* showFoldingControls */) === 'mouseover';
+                this.foldingDecorationProvider.showFoldingHighlights = options.get(37 /* foldingHighlight */);
                 this.onModelContentChanged();
             }
-            if (e.hasChanged(32 /* foldingStrategy */)) {
-                this._useFoldingProviders = this.editor.getOptions().get(32 /* foldingStrategy */) !== 'indentation';
+            if (e.hasChanged(36 /* foldingStrategy */)) {
+                this._useFoldingProviders = this.editor.getOptions().get(36 /* foldingStrategy */) !== 'indentation';
                 this.onFoldingStrategyChanged();
             }
-            if (e.hasChanged(34 /* unfoldOnClickAfterEndOfLine */)) {
-                this._unfoldOnClickAfterEndOfLine = this.editor.getOptions().get(34 /* unfoldOnClickAfterEndOfLine */);
+            if (e.hasChanged(38 /* unfoldOnClickAfterEndOfLine */)) {
+                this._unfoldOnClickAfterEndOfLine = this.editor.getOptions().get(38 /* unfoldOnClickAfterEndOfLine */);
             }
         }));
         this.onModelChanged();
@@ -119,7 +120,13 @@ let FoldingController = class FoldingController extends Disposable {
             if (foldingModel) {
                 foldingModel.then(foldingModel => {
                     if (foldingModel) {
-                        foldingModel.applyMemento(collapsedRegions);
+                        this._restoringViewState = true;
+                        try {
+                            foldingModel.applyMemento(collapsedRegions);
+                        }
+                        finally {
+                            this._restoringViewState = false;
+                        }
                     }
                 }).then(undefined, onUnexpectedError);
             }
@@ -192,7 +199,7 @@ let FoldingController = class FoldingController extends Disposable {
                 return rangeProvider; // keep memento in case there are still no foldingProviders on the next request.
             }
             else if (foldingProviders.length > 0) {
-                this.rangeProvider = new SyntaxRangeProvider(editorModel, foldingProviders);
+                this.rangeProvider = new SyntaxRangeProvider(editorModel, foldingProviders, () => this.onModelContentChanged());
             }
         }
         this.foldingStateMemento = null;
@@ -229,7 +236,7 @@ let FoldingController = class FoldingController extends Disposable {
         }
     }
     onHiddenRangesChanges(hiddenRanges) {
-        if (this.hiddenRangeModel && hiddenRanges.length) {
+        if (this.hiddenRangeModel && hiddenRanges.length && !this._restoringViewState) {
             let selections = this.editor.getSelections();
             if (selections) {
                 if (this.hiddenRangeModel.adjustSelections(selections)) {
@@ -341,18 +348,34 @@ let FoldingController = class FoldingController extends Disposable {
                 if (region && region.startLineNumber === lineNumber) {
                     let isCollapsed = region.isCollapsed;
                     if (iconClicked || isCollapsed) {
+                        let surrounding = e.event.altKey;
                         let toToggle = [];
-                        let recursive = e.event.middleButton || e.event.shiftKey;
-                        if (recursive) {
-                            for (const r of foldingModel.getRegionsInside(region)) {
-                                if (r.isCollapsed === isCollapsed) {
+                        if (surrounding) {
+                            let filter = (otherRegion) => !otherRegion.containedBy(region) && !region.containedBy(otherRegion);
+                            let toMaybeToggle = foldingModel.getRegionsInside(null, filter);
+                            for (const r of toMaybeToggle) {
+                                if (r.isCollapsed) {
                                     toToggle.push(r);
                                 }
                             }
+                            // if any surrounding regions are folded, unfold those. Otherwise, fold all surrounding
+                            if (toToggle.length === 0) {
+                                toToggle = toMaybeToggle;
+                            }
                         }
-                        // when recursive, first only collapse all children. If all are already folded or there are no children, also fold parent.
-                        if (isCollapsed || !recursive || toToggle.length === 0) {
-                            toToggle.push(region);
+                        else {
+                            let recursive = e.event.middleButton || e.event.shiftKey;
+                            if (recursive) {
+                                for (const r of foldingModel.getRegionsInside(region)) {
+                                    if (r.isCollapsed === isCollapsed) {
+                                        toToggle.push(r);
+                                    }
+                                }
+                            }
+                            // when recursive, first only collapse all children. If all are already folded or there are no children, also fold parent.
+                            if (isCollapsed || !recursive || toToggle.length === 0) {
+                                toToggle.push(region);
+                            }
                         }
                         foldingModel.toggleCollapseState(toToggle);
                         this.reveal({ lineNumber, column: 1 });
@@ -700,6 +723,44 @@ class UnfoldAllRegionsAction extends FoldingAction {
         }
     }
 }
+class FoldAllRegionsExceptAction extends FoldingAction {
+    constructor() {
+        super({
+            id: 'editor.foldAllExcept',
+            label: nls.localize('foldAllExcept.label', "Fold All Regions Except Selected"),
+            alias: 'Fold All Regions Except Selected',
+            precondition: CONTEXT_FOLDING_ENABLED,
+            kbOpts: {
+                kbExpr: EditorContextKeys.editorTextFocus,
+                primary: KeyChord(2048 /* CtrlCmd */ | 41 /* KEY_K */, 2048 /* CtrlCmd */ | 83 /* US_MINUS */),
+                weight: 100 /* EditorContrib */
+            }
+        });
+    }
+    invoke(_foldingController, foldingModel, editor) {
+        let selectedLines = this.getSelectedLines(editor);
+        setCollapseStateForRest(foldingModel, true, selectedLines);
+    }
+}
+class UnfoldAllRegionsExceptAction extends FoldingAction {
+    constructor() {
+        super({
+            id: 'editor.unfoldAllExcept',
+            label: nls.localize('unfoldAllExcept.label', "Unfold All Regions Except Selected"),
+            alias: 'Unfold All Regions Except Selected',
+            precondition: CONTEXT_FOLDING_ENABLED,
+            kbOpts: {
+                kbExpr: EditorContextKeys.editorTextFocus,
+                primary: KeyChord(2048 /* CtrlCmd */ | 41 /* KEY_K */, 2048 /* CtrlCmd */ | 81 /* US_EQUAL */),
+                weight: 100 /* EditorContrib */
+            }
+        });
+    }
+    invoke(_foldingController, foldingModel, editor) {
+        let selectedLines = this.getSelectedLines(editor);
+        setCollapseStateForRest(foldingModel, false, selectedLines);
+    }
+}
 class FoldAllAction extends FoldingAction {
     constructor() {
         super({
@@ -756,6 +817,8 @@ registerEditorAction(UnfoldAllAction);
 registerEditorAction(FoldAllBlockCommentsAction);
 registerEditorAction(FoldAllRegionsAction);
 registerEditorAction(UnfoldAllRegionsAction);
+registerEditorAction(FoldAllRegionsExceptAction);
+registerEditorAction(UnfoldAllRegionsExceptAction);
 registerEditorAction(ToggleFoldAction);
 for (let i = 1; i <= 7; i++) {
     registerInstantiatedEditorAction(new FoldLevelAction({
@@ -780,8 +843,8 @@ registerThemingParticipant((theme, collector) => {
     const editorFoldColor = theme.getColor(editorFoldForeground);
     if (editorFoldColor) {
         collector.addRule(`
-		.monaco-editor .cldr${foldingExpandedIcon.cssSelector},
-		.monaco-editor .cldr${foldingCollapsedIcon.cssSelector} {
+		.monaco-editor .cldr${ThemeIcon.asCSSSelector(foldingExpandedIcon)},
+		.monaco-editor .cldr${ThemeIcon.asCSSSelector(foldingCollapsedIcon)} {
 			color: ${editorFoldColor} !important;
 		}
 		`);
