@@ -7,10 +7,12 @@ var __extends = (this && this.__extends) || (function () {
     var extendStatics = function (d, b) {
         extendStatics = Object.setPrototypeOf ||
             ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
-            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
+            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
         return extendStatics(d, b);
     };
     return function (d, b) {
+        if (typeof b !== "function" && b !== null)
+            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
         extendStatics(d, b);
         function __() { this.constructor = d; }
         d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
@@ -18,7 +20,7 @@ var __extends = (this && this.__extends) || (function () {
 })();
 import * as nodes from '../parser/cssNodes.js';
 import { Scanner } from '../parser/cssScanner.js';
-import * as nls from '../../../fillers/vscode-nls.js';
+import * as nls from './../../../fillers/vscode-nls.js';
 var localize = nls.loadMessageBundle();
 var Element = /** @class */ (function () {
     function Element() {
@@ -433,7 +435,6 @@ var SelectorElementBuilder = /** @class */ (function () {
                     this.element = this.element.parent;
                 }
                 if (this.prev && this.prev.matches('~')) {
-                    this.element.addChild(toElement(selectorChild));
                     this.element.addChild(new LabelElement('\u22EE'));
                 }
                 var thisElement = toElement(selectorChild, parentElement);
