@@ -1125,10 +1125,7 @@ module.exports = {
 		"11.4.6",
 		"11.4.7",
 		"11.4.8",
-		"11.4.9",
-		"11.4.10",
-		"11.4.11",
-		"11.4.12"
+		"11.4.9"
 	],
 	"89.0.4328.0": [
 		"12.0.0-beta.1",
@@ -1226,12 +1223,7 @@ module.exports = {
 		"12.0.9",
 		"12.0.10",
 		"12.0.11",
-		"12.0.12",
-		"12.0.13",
-		"12.0.14",
-		"12.0.15",
-		"12.0.16",
-		"12.0.17"
+		"12.0.12"
 	],
 	"90.0.4402.0": [
 		"13.0.0-beta.2",
@@ -1343,20 +1335,7 @@ module.exports = {
 		"13.1.2"
 	],
 	"91.0.4472.106": [
-		"13.1.3",
-		"13.1.4"
-	],
-	"91.0.4472.124": [
-		"13.1.5",
-		"13.1.6",
-		"13.1.7"
-	],
-	"91.0.4472.164": [
-		"13.1.8",
-		"13.1.9",
-		"13.2.0",
-		"13.2.1",
-		"13.2.2"
+		"13.1.3"
 	],
 	"92.0.4511.0": [
 		"14.0.0-beta.1",
@@ -1383,52 +1362,6 @@ module.exports = {
 		"15.0.0-nightly.20210615",
 		"15.0.0-nightly.20210616"
 	],
-	"93.0.4539.0": [
-		"14.0.0-beta.9",
-		"14.0.0-beta.10",
-		"15.0.0-nightly.20210617",
-		"15.0.0-nightly.20210618",
-		"15.0.0-nightly.20210621",
-		"15.0.0-nightly.20210622"
-	],
-	"93.0.4557.4": [
-		"14.0.0-beta.11",
-		"14.0.0-beta.12"
-	],
-	"93.0.4566.0": [
-		"14.0.0-beta.13",
-		"14.0.0-beta.14",
-		"14.0.0-beta.15",
-		"14.0.0-beta.16",
-		"14.0.0-beta.17",
-		"15.0.0-alpha.1",
-		"15.0.0-alpha.2",
-		"15.0.0-nightly.20210706",
-		"15.0.0-nightly.20210707",
-		"15.0.0-nightly.20210708",
-		"15.0.0-nightly.20210709",
-		"15.0.0-nightly.20210712",
-		"15.0.0-nightly.20210713",
-		"15.0.0-nightly.20210714",
-		"15.0.0-nightly.20210715",
-		"15.0.0-nightly.20210716",
-		"15.0.0-nightly.20210719",
-		"15.0.0-nightly.20210720",
-		"15.0.0-nightly.20210721",
-		"16.0.0-nightly.20210722",
-		"16.0.0-nightly.20210723",
-		"16.0.0-nightly.20210726"
-	],
-	"93.0.4577.15": [
-		"14.0.0-beta.18",
-		"14.0.0-beta.19",
-		"14.0.0-beta.20",
-		"14.0.0-beta.21"
-	],
-	"93.0.4577.25": [
-		"14.0.0-beta.22",
-		"14.0.0-beta.23"
-	],
 	"92.0.4475.0": [
 		"14.0.0-nightly.20210426",
 		"14.0.0-nightly.20210427"
@@ -1456,37 +1389,6 @@ module.exports = {
 		"14.0.0-nightly.20210518",
 		"14.0.0-nightly.20210519"
 	],
-	"94.0.4584.0": [
-		"15.0.0-alpha.3",
-		"15.0.0-alpha.4",
-		"15.0.0-alpha.5",
-		"15.0.0-alpha.6",
-		"16.0.0-nightly.20210727",
-		"16.0.0-nightly.20210728",
-		"16.0.0-nightly.20210729",
-		"16.0.0-nightly.20210730",
-		"16.0.0-nightly.20210802",
-		"16.0.0-nightly.20210803",
-		"16.0.0-nightly.20210804",
-		"16.0.0-nightly.20210805",
-		"16.0.0-nightly.20210806",
-		"16.0.0-nightly.20210809",
-		"16.0.0-nightly.20210810",
-		"16.0.0-nightly.20210811"
-	],
-	"94.0.4590.2": [
-		"15.0.0-alpha.7",
-		"15.0.0-alpha.8",
-		"15.0.0-alpha.9",
-		"16.0.0-nightly.20210812",
-		"16.0.0-nightly.20210813",
-		"16.0.0-nightly.20210816",
-		"16.0.0-nightly.20210817",
-		"16.0.0-nightly.20210818",
-		"16.0.0-nightly.20210819",
-		"16.0.0-nightly.20210820",
-		"16.0.0-nightly.20210823"
-	],
 	"93.0.4530.0": [
 		"15.0.0-nightly.20210603",
 		"15.0.0-nightly.20210604"
@@ -1494,19 +1396,9 @@ module.exports = {
 	"93.0.4535.0": [
 		"15.0.0-nightly.20210608"
 	],
-	"93.0.4550.0": [
-		"15.0.0-nightly.20210623",
-		"15.0.0-nightly.20210624"
-	],
-	"93.0.4552.0": [
-		"15.0.0-nightly.20210625",
-		"15.0.0-nightly.20210628",
-		"15.0.0-nightly.20210629"
-	],
-	"93.0.4558.0": [
-		"15.0.0-nightly.20210630",
-		"15.0.0-nightly.20210701",
-		"15.0.0-nightly.20210702",
-		"15.0.0-nightly.20210705"
+	"93.0.4539.0": [
+		"15.0.0-nightly.20210617",
+		"15.0.0-nightly.20210618",
+		"15.0.0-nightly.20210621"
 	]
 };
\ No newline at end of file
