@@ -4,14 +4,15 @@ module.exports = {
   kResuming: Symbol('resuming'),
   kQueue: Symbol('queue'),
   kConnect: Symbol('connect'),
-  kResume: Symbol('resume'),
-  kPause: Symbol('pause'),
-  kSocketTimeout: Symbol('socket timeout'),
   kIdleTimeout: Symbol('idle timeout'),
+  kIdleTimeoutValue: Symbol('idle timeout value'),
+  kKeepAliveDefaultTimeout: Symbol('default keep alive timeout'),
   kKeepAliveMaxTimeout: Symbol('max keep alive timeout'),
   kKeepAliveTimeoutThreshold: Symbol('keep alive timeout threshold'),
-  kKeepAliveTimeout: Symbol('keep alive timeout'),
+  kKeepAliveTimeoutValue: Symbol('keep alive timeout'),
   kKeepAlive: Symbol('keep alive'),
+  kHeadersTimeout: Symbol('headers timeout'),
+  kBodyTimeout: Symbol('body timeout'),
   kTLSServerName: Symbol('server name'),
   kHost: Symbol('host'),
   kTLSOpts: Symbol('TLS Options'),
@@ -20,7 +21,6 @@ module.exports = {
   kReset: Symbol('reset'),
   kDestroyed: Symbol('destroyed'),
   kMaxHeadersSize: Symbol('max headers size'),
-  kHeadersTimeout: Symbol('headers timeout'),
   kRunningIdx: Symbol('running index'),
   kPendingIdx: Symbol('pending index'),
   kError: Symbol('error'),
@@ -28,9 +28,10 @@ module.exports = {
   kParser: Symbol('parser'),
   kOnDestroyed: Symbol('destroy callbacks'),
   kPipelining: Symbol('pipelinig'),
-  kRetryDelay: Symbol('retry delay'),
   kSocketPath: Symbol('socket path'),
   kSocket: Symbol('socket'),
-  kRetryTimeout: Symbol('retry timeout'),
-  kTLSSession: Symbol('tls session cache')
+  kTLSSession: Symbol('tls session cache'),
+  kHostHeader: Symbol('host header'),
+  kAgentOpts: Symbol('agent opts'),
+  kAgentCache: Symbol('agent cache')
 }
