@@ -101,6 +101,10 @@ Object.defineProperties(Reply.prototype, {
     set (value) {
       this.code(value)
     }
+  },
+  server: {
+    value: null,
+    writable: true
   }
 })
 
@@ -209,7 +213,11 @@ Reply.prototype.getHeaders = function () {
 }
 
 Reply.prototype.hasHeader = function (key) {
-  return this[kReplyHeaders][key.toLowerCase()] !== undefined
+  key = key.toLowerCase()
+  if (this[kReplyHeaders][key] !== undefined) {
+    return true
+  }
+  return this.raw.hasHeader(key)
 }
 
 Reply.prototype.removeHeader = function (key) {
@@ -244,8 +252,9 @@ Reply.prototype.header = function (key, value) {
 Reply.prototype.headers = function (headers) {
   const keys = Object.keys(headers)
   /* eslint-disable no-var */
-  for (var i = 0; i < keys.length; i++) {
-    this.header(keys[i], headers[keys[i]])
+  for (var i = 0; i !== keys.length; ++i) {
+    const key = keys[i]
+    this.header(key, headers[key])
   }
   return this
 }
@@ -319,12 +328,14 @@ Reply.prototype.then = function (fulfilled, rejected) {
     return
   }
 
-  eos(this.raw, function (err) {
+  eos(this.raw, (err) => {
     // We must not treat ERR_STREAM_PREMATURE_CLOSE as
     // an error because it is created by eos, not by the stream.
     if (err && err.code !== 'ERR_STREAM_PREMATURE_CLOSE') {
       if (rejected) {
         rejected(err)
+      } else {
+        this.log && this.log.warn('unhandled rejection on reply.then')
       }
     } else {
       fulfilled()
@@ -421,6 +432,8 @@ function onSendEnd (reply, payload) {
 
   if (!reply[kReplyHeaders]['content-length']) {
     reply[kReplyHeaders]['content-length'] = '' + Buffer.byteLength(payload)
+  } else if (req.raw.method !== 'HEAD' && reply[kReplyHeaders]['content-length'] !== Buffer.byteLength(payload)) {
+    reply[kReplyHeaders]['content-length'] = '' + Buffer.byteLength(payload)
   }
 
   reply[kReplySent] = true
@@ -462,21 +475,19 @@ function sendStream (payload, res, reply) {
   })
 
   eos(res, function (err) {
-    if (err != null) {
-      if (sourceOpen) {
-        if (res.headersSent) {
-          if (!errorLogged) {
-            errorLogged = true
-            logStreamError(reply.log, err, res)
-          }
-        }
-        if (payload.destroy) {
-          payload.destroy()
-        } else if (typeof payload.close === 'function') {
-          payload.close(noop)
-        } else if (typeof payload.abort === 'function') {
-          payload.abort()
-        }
+    if (sourceOpen) {
+      if (err != null && res.headersSent && !errorLogged) {
+        errorLogged = true
+        logStreamError(reply.log, err, res)
+      }
+      if (typeof payload.destroy === 'function') {
+        payload.destroy()
+      } else if (typeof payload.close === 'function') {
+        payload.close(noop)
+      } else if (typeof payload.abort === 'function') {
+        payload.abort()
+      } else {
+        reply.log.warn('stream payload does not end properly')
       }
     }
   })
@@ -543,19 +554,31 @@ function handleError (reply, error, cb) {
     return
   }
 
-  const serializerFn = getSchemaSerializer(reply.context, statusCode)
-  const payload = (serializerFn === false)
-    ? serializeError({
-        error: statusCodes[statusCode + ''],
-        code: error.code,
-        message: error.message || '',
-        statusCode: statusCode
-      })
-    : serializerFn(Object.create(error, {
-      error: { value: statusCodes[statusCode + ''] },
-      message: { value: error.message || '' },
-      statusCode: { value: statusCode }
-    }))
+  let payload
+  try {
+    const serializerFn = getSchemaSerializer(reply.context, statusCode)
+    payload = (serializerFn === false)
+      ? serializeError({
+          error: statusCodes[statusCode + ''],
+          code: error.code,
+          message: error.message || '',
+          statusCode: statusCode
+        })
+      : serializerFn(Object.create(error, {
+        error: { value: statusCodes[statusCode + ''] },
+        message: { value: error.message || '' },
+        statusCode: { value: statusCode }
+      }))
+  } catch (err) {
+    // error is always FST_ERR_SCH_SERIALIZATION_BUILD because this is called from route/compileSchemasForSerialization
+    reply.log.error({ err, statusCode: res.statusCode }, 'The serializer for the given status code failed')
+    res.statusCode = 500
+    payload = serializeError({
+      error: statusCodes['500'],
+      message: err.message,
+      statusCode: 500
+    })
+  }
 
   flatstr(payload)
   reply[kReplyHeaders]['content-type'] = CONTENT_TYPE.JSON
