@@ -4,7 +4,6 @@ import typescript from 'typescript';
 const globals = {
   __proto__: null,
   tslib: "tslib",
-  "@ungap/global-this": "globalThisPolyfill",
 };
 
 function external(id) {
@@ -12,10 +11,10 @@ function external(id) {
 }
 
 export default [{
-  input: "src/invariant.ts",
+  input: "src/trie.ts",
   external,
   output: {
-    file: "lib/invariant.esm.js",
+    file: "lib/trie.esm.js",
     format: "esm",
     sourcemap: true,
     globals,
@@ -27,15 +26,15 @@ export default [{
     }),
   ],
 }, {
-  input: "lib/invariant.esm.js",
+  input: "lib/trie.esm.js",
   external,
   output: {
-    // Intentionally overwrite the invariant.js file written by tsc:
-    file: "lib/invariant.js",
+    // Intentionally overwrite the trie.js file written by tsc:
+    file: "lib/trie.js",
     format: "cjs",
     exports: "named",
     sourcemap: true,
-    name: "ts-invariant",
+    name: "trie",
     globals,
   },
 }];
