@@ -13,12 +13,12 @@ const e = new Error('kaboom')
 app.use(function (f, opts) {
   return Promise.reject(e)
 }).after(function (err, cb) {
-  t.is(err, e)
+  t.equal(err, e)
   cb(err)
 }).after(function () {
   t.pass('this is just called')
 }).after(function (err, cb) {
-  t.is(err, e)
+  t.equal(err, e)
   cb(err)
 })
 
@@ -26,5 +26,5 @@ app.ready().then(() => {
   t.fail('this should not be called')
 }).catch(err => {
   t.ok(err)
-  t.strictEqual(err.message, 'kaboom')
+  t.equal(err.message, 'kaboom')
 })
