@@ -9,7 +9,7 @@ const get = require('simple-get').concat
 const instance = Fastify()
 
 t.plan(11)
-t.tearDown(instance.close.bind(instance))
+t.teardown(instance.close.bind(instance))
 
 const target = http.createServer((req, res) => {
   t.pass('request proxied')
@@ -26,13 +26,15 @@ instance.get('/', (request, reply) => {
   reply.from()
 })
 
-t.tearDown(target.close.bind(target))
+t.teardown(target.close.bind(target))
 
 target.listen(0, (err) => {
   t.error(err)
 
   instance.register(From, {
-    base: `http://localhost:${target.address().port}`
+    base: `http://localhost:${target.address().port}`,
+    // Use node core HTTP, Undici requires spec compliance
+    http: {}
   })
 
   instance.listen(0, (err) => {
