@@ -2,7 +2,7 @@
 
 const t = require('tap')
 const test = t.test
-const fp = require('../plugin')
+const fp = require('./../')
 
 test('anonymous function should be named mu1tip1e.composite.test', t => {
   t.plan(2)
@@ -11,6 +11,6 @@ test('anonymous function should be named mu1tip1e.composite.test', t => {
     next()
   })
 
-  t.is(fn[Symbol.for('plugin-meta')].name, 'mu1tip1e.composite.test-auto-0')
-  t.is(fn[Symbol.for('fastify.display-name')], 'mu1tip1e.composite.test-auto-0')
+  t.is(fn[Symbol.for('plugin-meta')].name, 'mu1tip1e.composite.test')
+  t.is(fn[Symbol.for('fastify.display-name')], 'mu1tip1e.composite.test')
 })
