@@ -3,7 +3,7 @@
 const proxyquire = require('proxyquire')
 const { test } = require('tap')
 const undici = require('..')
-const { Pool, errors } = require('..')
+const { Client, Pool, errors } = require('..')
 const { createServer } = require('http')
 const { EventEmitter } = require('events')
 const { promisify } = require('util')
@@ -12,31 +12,122 @@ const eos = require('stream').finished
 const net = require('net')
 const EE = require('events')
 
-test('basic get', (t) => {
-  t.plan(9)
+test('connect/disconnect event(s)', (t) => {
+  const clients = 2
+
+  t.plan(clients * 6)
 
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('GET', req.method)
+    res.writeHead(200, {
+      Connection: 'keep-alive',
+      'Keep-Alive': 'timeout=1s'
+    })
+    res.end('ok')
+  })
+  t.teardown(server.close.bind(server))
+
+  server.listen(0, () => {
+    const pool = new Pool(`http://localhost:${server.address().port}`, {
+      connections: clients,
+      keepAliveTimeoutThreshold: 100
+    })
+    t.teardown(pool.close.bind(pool))
+
+    pool.on('connect', (client) => {
+      t.equal(client instanceof Client, true)
+    })
+    pool.on('disconnect', (client, error) => {
+      t.ok(client instanceof Client)
+      t.ok(error instanceof errors.InformationalError)
+      t.equal(error.code, 'UND_ERR_INFO')
+      t.equal(error.message, 'socket idle timeout')
+    })
+
+    for (let i = 0; i < clients; i++) {
+      pool.request({
+        path: '/',
+        method: 'GET'
+      }, (err, { headers, body }) => {
+        t.error(err)
+        body.resume()
+      })
+    }
+  })
+})
+
+test('basic get', (t) => {
+  t.plan(14)
+
+  const server = createServer((req, res) => {
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
     res.setHeader('content-type', 'text/plain')
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = undici(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
+
+    t.equal(client.url.origin, `http://localhost:${server.address().port}`)
 
     client.request({ path: '/', method: 'GET' }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
+      })
+    })
+
+    t.equal(client.destroyed, false)
+    t.equal(client.closed, false)
+    client.close((err) => {
+      t.error(err)
+      t.equal(client.destroyed, true)
+      client.destroy((err) => {
+        t.error(err)
+        client.close((err) => {
+          t.ok(err instanceof errors.ClientDestroyedError)
+        })
+      })
+    })
+    t.equal(client.closed, true)
+  })
+})
+
+test('URL as arg', (t) => {
+  t.plan(9)
+
+  const server = createServer((req, res) => {
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
+    res.setHeader('content-type', 'text/plain')
+    res.end('hello')
+  })
+  t.teardown(server.close.bind(server))
+
+  server.listen(0, async () => {
+    const url = new URL('http://localhost')
+    url.port = server.address().port
+    const client = undici(url)
+    t.teardown(client.destroy.bind(client))
+
+    client.request({ path: '/', method: 'GET' }, (err, { statusCode, headers, body }) => {
+      t.error(err)
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
+      const bufs = []
+      body.on('data', (buf) => {
+        bufs.push(buf)
+      })
+      body.on('end', () => {
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
 
@@ -58,11 +149,11 @@ test('basic get error async/await', (t) => {
   const server = createServer((req, res) => {
     res.destroy()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = undici(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     await client.request({ path: '/', method: 'GET' })
       .catch((err) => {
@@ -79,20 +170,20 @@ test('basic get error async/await', (t) => {
 
 test('basic get with async/await', async (t) => {
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('GET', req.method)
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
     res.setHeader('content-type', 'text/plain')
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   await promisify(server.listen.bind(server))(0)
   const client = new Pool(`http://localhost:${server.address().port}`)
-  t.tearDown(client.destroy.bind(client))
+  t.teardown(client.destroy.bind(client))
 
   const { statusCode, headers, body } = await client.request({ path: '/', method: 'GET' })
-  t.strictEqual(statusCode, 200)
-  t.strictEqual(headers['content-type'], 'text/plain')
+  t.equal(statusCode, 200)
+  t.equal(headers['content-type'], 'text/plain')
 
   body.resume()
   await promisify(eos)(body)
@@ -103,20 +194,20 @@ test('basic get with async/await', async (t) => {
 
 test('stream get async/await', async (t) => {
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('GET', req.method)
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
     res.setHeader('content-type', 'text/plain')
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   await promisify(server.listen.bind(server))(0)
   const client = new Pool(`http://localhost:${server.address().port}`)
-  t.tearDown(client.destroy.bind(client))
+  t.teardown(client.destroy.bind(client))
 
   await client.stream({ path: '/', method: 'GET' }, ({ statusCode, headers }) => {
-    t.strictEqual(statusCode, 200)
-    t.strictEqual(headers['content-type'], 'text/plain')
+    t.equal(statusCode, 200)
+    t.equal(headers['content-type'], 'text/plain')
     return new PassThrough()
   })
 })
@@ -127,11 +218,11 @@ test('stream get error async/await', (t) => {
   const server = createServer((req, res) => {
     res.destroy()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = undici(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     await client.stream({ path: '/', method: 'GET' }, () => {
 
@@ -146,21 +237,21 @@ test('pipeline get', (t) => {
   t.plan(5)
 
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('GET', req.method)
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
     res.setHeader('content-type', 'text/plain')
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = undici(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     const bufs = []
     client.pipeline({ path: '/', method: 'GET' }, ({ statusCode, headers, body }) => {
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       return body
     })
       .end()
@@ -168,7 +259,7 @@ test('pipeline get', (t) => {
         bufs.push(buf)
       })
       .on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
   })
 })
@@ -204,17 +295,15 @@ test('backpressure algorithm', (t) => {
 
   const pool = new Pool('http://notanhost')
 
-  t.strictEqual(total, 10)
-
   pool.dispatch({}, noop)
   pool.dispatch({}, noop)
 
   const d1 = seen.shift() // d1 = c0
-  t.strictEqual(d1.id, 0)
+  t.equal(d1.id, 0)
   const d2 = seen.shift() // d1 = c0
-  t.strictEqual(d1.id, 0)
+  t.equal(d1.id, 0)
 
-  t.strictEqual(d1.id, d2.id)
+  t.equal(d1.id, d2.id)
 
   pool.dispatch({}, noop) // d3 = c0
 
@@ -223,12 +312,12 @@ test('backpressure algorithm', (t) => {
   pool.dispatch({}, noop) // d4 = c1
 
   const d3 = seen.shift()
-  t.strictEqual(d3.id, 0)
+  t.equal(d3.id, 0)
   const d4 = seen.shift()
-  t.strictEqual(d4.id, 1)
+  t.equal(d4.id, 1)
 
-  t.strictEqual(d3.id, d2.id)
-  t.notStrictEqual(d3.id, d4.id)
+  t.equal(d3.id, d2.id)
+  t.not(d3.id, d4.id)
 
   pool.dispatch({}, noop) // d5 = c1
 
@@ -237,12 +326,14 @@ test('backpressure algorithm', (t) => {
   pool.dispatch({}, noop) // d6 = c0
 
   const d5 = seen.shift()
-  t.strictEqual(d5.id, 1)
+  t.equal(d5.id, 1)
   const d6 = seen.shift()
-  t.strictEqual(d6.id, 0)
+  t.equal(d6.id, 0)
 
-  t.strictEqual(d5.id, d4.id)
-  t.strictEqual(d3.id, d6.id)
+  t.equal(d5.id, d4.id)
+  t.equal(d3.id, d6.id)
+
+  t.equal(total, 2)
 
   t.end()
 })
@@ -250,62 +341,67 @@ test('backpressure algorithm', (t) => {
 function noop () {}
 
 test('busy', (t) => {
-  t.plan(8 * 6)
+  t.plan(8 * 10 + 2 + 1)
 
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('GET', req.method)
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
     res.setHeader('content-type', 'text/plain')
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = undici(`http://localhost:${server.address().port}`, {
       connections: 2,
       pipelining: 2
     })
-    t.tearDown(client.destroy.bind(client))
+    let connected = 0
+    client.on('drain', () => {
+      t.pass()
+    })
+    client.on('connect', () => {
+      t.equal(client.connected, ++connected)
+    })
 
-    for (let n = 0; n < 8; ++n) {
+    t.teardown(client.destroy.bind(client))
+
+    for (let n = 1; n <= 8; ++n) {
       client.request({ path: '/', method: 'GET' }, (err, { statusCode, headers, body }) => {
         t.error(err)
-        t.strictEqual(statusCode, 200)
-        t.strictEqual(headers['content-type'], 'text/plain')
+        t.equal(statusCode, 200)
+        t.equal(headers['content-type'], 'text/plain')
         const bufs = []
         body.on('data', (buf) => {
           bufs.push(buf)
         })
         body.on('end', () => {
-          t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+          t.equal('hello', Buffer.concat(bufs).toString('utf8'))
         })
       })
+      t.equal(client.pending, n)
+      t.equal(client.busy, n >= 2)
+      t.equal(client.size, n)
+      t.equal(client.running, 0)
     }
   })
 })
 
 test('invalid options throws', (t) => {
-  t.plan(6)
-
-  try {
-    new Pool(null, { connections: 0 }) // eslint-disable-line
-  } catch (err) {
-    t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid connections')
-  }
+  t.plan(4)
 
   try {
     new Pool(null, { connections: -1 }) // eslint-disable-line
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid connections')
+    t.equal(err.message, 'invalid connections')
   }
 
   try {
     new Pool(null, { connections: true }) // eslint-disable-line
   } catch (err) {
     t.ok(err instanceof errors.InvalidArgumentError)
-    t.strictEqual(err.message, 'invalid connections')
+    t.equal(err.message, 'invalid connections')
   }
 })
 
@@ -326,11 +422,11 @@ test('pool upgrade promise', (t) => {
       c.end()
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     const { headers, socket } = await client.upgrade({
       path: '/',
@@ -344,10 +440,10 @@ test('pool upgrade promise', (t) => {
     })
 
     socket.on('close', () => {
-      t.strictEqual(recvData.toString(), 'Body')
+      t.equal(recvData.toString(), 'Body')
     })
 
-    t.deepEqual(headers, {
+    t.same(headers, {
       hello: 'world',
       connection: 'upgrade',
       upgrade: 'websocket'
@@ -374,11 +470,11 @@ test('pool connect', (t) => {
       socket.end(data)
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     const { socket } = await client.connect({
       path: '/'
@@ -390,7 +486,7 @@ test('pool connect', (t) => {
     })
 
     socket.on('end', () => {
-      t.strictEqual(recvData.toString(), 'Body')
+      t.equal(recvData.toString(), 'Body')
     })
 
     socket.write('Body')
@@ -404,11 +500,11 @@ test('pool dispatch', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     let buf = ''
     client.dispatch({
@@ -418,13 +514,15 @@ test('pool dispatch', (t) => {
       onConnect () {
       },
       onHeaders (statusCode, headers) {
-        t.strictEqual(statusCode, 200)
+        t.equal(statusCode, 200)
       },
       onData (chunk) {
         buf += chunk
       },
       onComplete () {
-        t.strictEqual(buf, 'asd')
+        t.equal(buf, 'asd')
+      },
+      onError () {
       }
     })
   })
@@ -448,13 +546,13 @@ test('300 requests succeed', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     for (let n = 0; n < 300; ++n) {
       client.request({
@@ -463,7 +561,7 @@ test('300 requests succeed', (t) => {
       }, (err, data) => {
         t.error(err)
         data.body.on('data', (chunk) => {
-          t.strictEqual(chunk.toString(), 'asd')
+          t.equal(chunk.toString(), 'asd')
         }).on('end', () => {
           t.pass()
         })
@@ -481,11 +579,11 @@ test('pool connect error', (t) => {
   server.on('connect', (req, socket, firstBodyChunk) => {
     socket.destroy()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     try {
       await client.connect({
@@ -513,11 +611,11 @@ test('pool upgrade error', (t) => {
       // Ignore error.
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     try {
       await client.upgrade({
@@ -537,14 +635,14 @@ test('pool dispatch error', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.dispatch({
       path: '/',
@@ -553,12 +651,14 @@ test('pool dispatch error', (t) => {
       onConnect () {
       },
       onHeaders (statusCode, headers) {
-        t.strictEqual(statusCode, 200)
+        t.equal(statusCode, 200)
       },
       onData (chunk) {
       },
       onComplete () {
         t.pass()
+      },
+      onError () {
       }
     })
 
@@ -579,7 +679,7 @@ test('pool dispatch error', (t) => {
         t.fail()
       },
       onError (err) {
-        t.strictEqual(err.code, 'UND_ERR_INVALID_ARG')
+        t.equal(err.code, 'UND_ERR_INVALID_ARG')
       }
     })
   })
@@ -591,14 +691,14 @@ test('pool request abort in queue', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.dispatch({
       path: '/',
@@ -607,12 +707,14 @@ test('pool request abort in queue', (t) => {
       onConnect () {
       },
       onHeaders (statusCode, headers) {
-        t.strictEqual(statusCode, 200)
+        t.equal(statusCode, 200)
       },
       onData (chunk) {
       },
       onComplete () {
         t.pass()
+      },
+      onError () {
       }
     })
 
@@ -622,7 +724,7 @@ test('pool request abort in queue', (t) => {
       method: 'GET',
       signal
     }, (err) => {
-      t.strictEqual(err.code, 'UND_ERR_ABORTED')
+      t.equal(err.code, 'UND_ERR_ABORTED')
     })
     signal.emit('abort')
   })
@@ -634,14 +736,14 @@ test('pool stream abort in queue', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.dispatch({
       path: '/',
@@ -650,12 +752,14 @@ test('pool stream abort in queue', (t) => {
       onConnect () {
       },
       onHeaders (statusCode, headers) {
-        t.strictEqual(statusCode, 200)
+        t.equal(statusCode, 200)
       },
       onData (chunk) {
       },
       onComplete () {
         t.pass()
+      },
+      onError () {
       }
     })
 
@@ -665,7 +769,7 @@ test('pool stream abort in queue', (t) => {
       method: 'GET',
       signal
     }, ({ body }) => body, (err) => {
-      t.strictEqual(err.code, 'UND_ERR_ABORTED')
+      t.equal(err.code, 'UND_ERR_ABORTED')
     })
     signal.emit('abort')
   })
@@ -677,14 +781,14 @@ test('pool pipeline abort in queue', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.dispatch({
       path: '/',
@@ -693,12 +797,14 @@ test('pool pipeline abort in queue', (t) => {
       onConnect () {
       },
       onHeaders (statusCode, headers) {
-        t.strictEqual(statusCode, 200)
+        t.equal(statusCode, 200)
       },
       onData (chunk) {
       },
       onComplete () {
         t.pass()
+      },
+      onError () {
       }
     })
 
@@ -708,7 +814,7 @@ test('pool pipeline abort in queue', (t) => {
       method: 'GET',
       signal
     }, ({ body }) => body).end().on('error', (err) => {
-      t.strictEqual(err.code, 'UND_ERR_ABORTED')
+      t.equal(err.code, 'UND_ERR_ABORTED')
     })
     signal.emit('abort')
   })
@@ -720,14 +826,14 @@ test('pool stream constructor error destroy body', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     {
       const body = new Readable({
@@ -744,8 +850,8 @@ test('pool stream constructor error destroy body', (t) => {
       }, () => {
         t.fail()
       }, (err) => {
-        t.strictEqual(err.code, 'UND_ERR_INVALID_ARG')
-        t.strictEqual(body.destroyed, true)
+        t.equal(err.code, 'UND_ERR_INVALID_ARG')
+        t.equal(body.destroyed, true)
       })
     }
 
@@ -761,8 +867,8 @@ test('pool stream constructor error destroy body', (t) => {
       }, () => {
         t.fail()
       }, (err) => {
-        t.strictEqual(err.code, 'UND_ERR_INVALID_ARG')
-        t.strictEqual(body.destroyed, true)
+        t.equal(err.code, 'UND_ERR_INVALID_ARG')
+        t.equal(body.destroyed, true)
       })
     }
   })
@@ -774,14 +880,14 @@ test('pool request constructor error destroy body', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     {
       const body = new Readable({
@@ -796,8 +902,8 @@ test('pool request constructor error destroy body', (t) => {
           'transfer-encoding': 'fail'
         }
       }, (err) => {
-        t.strictEqual(err.code, 'UND_ERR_INVALID_ARG')
-        t.strictEqual(body.destroyed, true)
+        t.equal(err.code, 'UND_ERR_INVALID_ARG')
+        t.equal(body.destroyed, true)
       })
     }
 
@@ -811,8 +917,8 @@ test('pool request constructor error destroy body', (t) => {
         method: 'CONNECT',
         body
       }, (err) => {
-        t.strictEqual(err.code, 'UND_ERR_INVALID_ARG')
-        t.strictEqual(body.destroyed, true)
+        t.equal(err.code, 'UND_ERR_INVALID_ARG')
+        t.equal(body.destroyed, true)
       })
     }
   })
@@ -824,14 +930,14 @@ test('pool close waits for all requests', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -870,14 +976,14 @@ test('pool destroyed', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.destroy()
     client.request({
@@ -890,38 +996,40 @@ test('pool destroyed', (t) => {
 })
 
 test('pool destroy fails queued requests', (t) => {
-  t.plan(4)
+  t.plan(6)
 
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, async () => {
     const client = new Pool(`http://localhost:${server.address().port}`, {
       connections: 1,
       pipelining: 1
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     const _err = new Error()
     client.request({
       path: '/',
       method: 'GET'
     }, (err) => {
-      t.strictEqual(err, _err)
+      t.equal(err, _err)
     })
 
     client.request({
       path: '/',
       method: 'GET'
     }, (err) => {
-      t.strictEqual(err, _err)
+      t.equal(err, _err)
     })
 
+    t.equal(client.destroyed, false)
     client.destroy(_err, () => {
       t.pass()
     })
+    t.equal(client.destroyed, true)
 
     client.request({
       path: '/',
