@@ -35,6 +35,9 @@ const innerIndex = fs
 const allThreeBr = fs.readFileSync(
   './test/static-pre-compressed/all-three.html.br'
 )
+const allThreeGzip = fs.readFileSync(
+  './test/static-pre-compressed/all-three.html.gz'
+)
 const gzipOnly = fs.readFileSync(
   './test/static-pre-compressed/gzip-only.html.gz'
 )
@@ -748,6 +751,49 @@ t.test('not found responses can be customized with fastify.setNotFoundHandler()'
   })
 })
 
+t.test('fastify.setNotFoundHandler() is called for dotfiles when when send is configured to ignore dotfiles', t => {
+  t.plan(2)
+
+  const pluginOptions = {
+    root: path.join(__dirname, '/static'),
+    send: {
+      dotfiles: 'ignore'
+    }
+  }
+  const fastify = Fastify()
+
+  fastify.setNotFoundHandler(function notFoundHandler (request, reply) {
+    reply.code(404).type('text/plain').send(request.raw.url + ' Not Found')
+  })
+
+  fastify.register(fastifyStatic, pluginOptions)
+
+  t.teardown(fastify.close.bind(fastify))
+
+  fastify.listen(0, err => {
+    t.error(err)
+
+    fastify.server.unref()
+
+    // Requesting files with a leading dot doesn't follow the same code path as
+    // other 404 errors
+    t.test('/path/does/not/.exist.html', t => {
+      t.plan(4)
+
+      simple.concat({
+        method: 'GET',
+        url: 'http://localhost:' + fastify.server.address().port + '/path/does/not/.exist.html',
+        followRedirect: false
+      }, (err, response, body) => {
+        t.error(err)
+        t.equal(response.statusCode, 404)
+        t.equal(response.headers['content-type'], 'text/plain')
+        t.equal(body.toString(), '/path/does/not/.exist.html Not Found')
+      })
+    })
+  })
+})
+
 t.test('serving disabled', (t) => {
   t.plan(3)
 
@@ -797,13 +843,14 @@ t.test('serving disabled', (t) => {
 })
 
 t.test('sendFile', (t) => {
-  t.plan(4)
+  t.plan(5)
 
   const pluginOptions = {
     root: path.join(__dirname, '/static'),
     prefix: '/static'
   }
   const fastify = Fastify()
+  const maxAge = Math.round(Math.random() * 10) * 10000
   fastify.register(fastifyStatic, pluginOptions)
 
   fastify.get('/foo/bar', function (req, reply) {
@@ -817,6 +864,10 @@ t.test('sendFile', (t) => {
     )
   })
 
+  fastify.get('/foo/bar/options/override/test', function (req, reply) {
+    return reply.sendFile('/index.html', { maxAge })
+  })
+
   fastify.listen(0, (err) => {
     t.error(err)
 
@@ -863,6 +914,21 @@ t.test('sendFile', (t) => {
         genericResponseChecks(t, response)
       })
     })
+
+    t.test('reply.sendFile() with options', (t) => {
+      t.plan(4 + GENERIC_RESPONSE_CHECK_COUNT)
+      simple.concat({
+        method: 'GET',
+        url: 'http://localhost:' + fastify.server.address().port + '/foo/bar/options/override/test',
+        followRedirect: false
+      }, (err, response, body) => {
+        t.error(err)
+        t.equal(response.statusCode, 200)
+        t.equal(response.headers['cache-control'], `public, max-age=${maxAge / 1000}`)
+        t.equal(body.toString(), indexContent)
+        genericResponseChecks(t, response)
+      })
+    })
   })
 })
 
@@ -2952,6 +3018,66 @@ t.test(
   }
 )
 
+t.test(
+  'will serve pre-compressed files with .gzip if * directive used',
+  async (t) => {
+    const pluginOptions = {
+      root: path.join(__dirname, '/static-pre-compressed'),
+      prefix: '/static-pre-compressed/',
+      preCompressed: true
+    }
+
+    const fastify = Fastify()
+
+    fastify.register(fastifyStatic, pluginOptions)
+    t.teardown(fastify.close.bind(fastify))
+
+    const response = await fastify.inject({
+      method: 'GET',
+      url: '/static-pre-compressed/all-three.html',
+      headers: {
+        'accept-encoding': '*'
+      }
+    })
+
+    genericResponseChecks(t, response)
+    t.equal(response.headers['content-encoding'], 'gzip')
+    t.equal(response.statusCode, 200)
+    t.same(response.rawPayload, allThreeGzip)
+    t.end()
+  }
+)
+
+t.test(
+  'will serve pre-compressed files with .gzip if multiple * directives used',
+  async (t) => {
+    const pluginOptions = {
+      root: path.join(__dirname, '/static-pre-compressed'),
+      prefix: '/static-pre-compressed/',
+      preCompressed: true
+    }
+
+    const fastify = Fastify()
+
+    fastify.register(fastifyStatic, pluginOptions)
+    t.teardown(fastify.close.bind(fastify))
+
+    const response = await fastify.inject({
+      method: 'GET',
+      url: '/static-pre-compressed/all-three.html',
+      headers: {
+        'accept-encoding': '*, *'
+      }
+    })
+
+    genericResponseChecks(t, response)
+    t.equal(response.headers['content-encoding'], 'gzip')
+    t.equal(response.statusCode, 200)
+    t.same(response.rawPayload, allThreeGzip)
+    t.end()
+  }
+)
+
 t.test(
   'will serve uncompressed files if there are no compressed variants on disk',
   async (t) => {
@@ -3014,7 +3140,7 @@ t.test(
 )
 
 t.test(
-  'will serve pre-compressed files and fallback to .gz if .br is not on disk  (with wildcard: false) ',
+  'will serve pre-compressed files and fallback to .gz if .br is not on disk (with wildcard: false)',
   async (t) => {
     const pluginOptions = {
       root: path.join(__dirname, '/static-pre-compressed'),
@@ -3045,7 +3171,69 @@ t.test(
 )
 
 t.test(
-  'will serve uncompressed files if there are no compressed variants on disk  (with wildcard: false)',
+  'will serve pre-compressed files with .gzip if * directive used (with wildcard: false)',
+  async (t) => {
+    const pluginOptions = {
+      root: path.join(__dirname, '/static-pre-compressed'),
+      prefix: '/static-pre-compressed/',
+      preCompressed: true,
+      wildcard: false
+    }
+
+    const fastify = Fastify()
+
+    fastify.register(fastifyStatic, pluginOptions)
+    t.teardown(fastify.close.bind(fastify))
+
+    const response = await fastify.inject({
+      method: 'GET',
+      url: '/static-pre-compressed/all-three.html',
+      headers: {
+        'accept-encoding': '*'
+      }
+    })
+
+    genericResponseChecks(t, response)
+    t.equal(response.headers['content-encoding'], 'gzip')
+    t.equal(response.statusCode, 200)
+    t.same(response.rawPayload, allThreeGzip)
+    t.end()
+  }
+)
+
+t.test(
+  'will serve pre-compressed files with .gzip if multiple * directives used (with wildcard: false)',
+  async (t) => {
+    const pluginOptions = {
+      root: path.join(__dirname, '/static-pre-compressed'),
+      prefix: '/static-pre-compressed/',
+      preCompressed: true,
+      wildcard: false
+    }
+
+    const fastify = Fastify()
+
+    fastify.register(fastifyStatic, pluginOptions)
+    t.teardown(fastify.close.bind(fastify))
+
+    const response = await fastify.inject({
+      method: 'GET',
+      url: '/static-pre-compressed/all-three.html',
+      headers: {
+        'accept-encoding': '*, *'
+      }
+    })
+
+    genericResponseChecks(t, response)
+    t.equal(response.headers['content-encoding'], 'gzip')
+    t.equal(response.statusCode, 200)
+    t.same(response.rawPayload, allThreeGzip)
+    t.end()
+  }
+)
+
+t.test(
+  'will serve uncompressed files if there are no compressed variants on disk (with wildcard: false)',
   async (t) => {
     const pluginOptions = {
       root: path.join(__dirname, '/static-pre-compressed'),
@@ -3219,3 +3407,42 @@ t.test(
     t.end()
   }
 )
+
+t.test('should not redirect to protocol-relative locations', (t) => {
+  const urls = [
+    ['//^/..', '/', 301],
+    ['//^/.', null, 404], // it is NOT recognized as a directory by pillarjs/send
+    ['//:/..', '/', 301],
+    ['/\\\\a//google.com/%2e%2e%2f%2e%2e', '/a//google.com/%2e%2e%2f%2e%2e/', 301],
+    ['//a//youtube.com/%2e%2e%2f%2e%2e', '/a//youtube.com/%2e%2e%2f%2e%2e/', 301],
+    ['/^', null, 404], // it is NOT recognized as a directory by pillarjs/send
+    ['//google.com/%2e%2e', '/', 301],
+    ['//users/%2e%2e', '/', 301],
+    ['//users', null, 404],
+    ['///deep/path//for//test//index.html', null, 200]
+  ]
+
+  t.plan(1 + urls.length * 2)
+  const fastify = Fastify()
+  fastify.register(fastifyStatic, {
+    root: path.join(__dirname, '/static'),
+    redirect: true
+  })
+  t.teardown(fastify.close.bind(fastify))
+  fastify.listen(0, (err, address) => {
+    t.error(err)
+    urls.forEach(([testUrl, expected, status]) => {
+      const req = http.request(url.parse(address + testUrl), res => {
+        t.equal(res.statusCode, status, `status ${testUrl}`)
+
+        if (expected) {
+          t.equal(res.headers.location, expected)
+        } else {
+          t.notOk(res.headers.location)
+        }
+      })
+      req.on('error', t.error)
+      req.end()
+    })
+  })
+})
